@@ -52,7 +52,7 @@ type 'a file_impl = {
     mutable impl_file_ops : 'a file_ops;
     mutable impl_file_size : int64;
     mutable impl_file_age : int;
-    mutable impl_file_fd : Unix32.t;
+    mutable impl_file_fd : Unix32.t option;
     mutable impl_file_downloaded : int64;
     mutable impl_file_received : int64;
     mutable impl_file_last_received : (int64 * int) list;
@@ -95,6 +95,7 @@ it will happen soon. *)
     mutable op_file_proposed_filenames : ('a -> string list);
   }
 
+
 (*************************************************************************)
 (*                                                                       *)
 (*                         as_file...                                    *)
@@ -121,7 +122,7 @@ let dummy_file_impl = {
     impl_file_ops = Obj.magic 0;
     impl_file_size = Int64.zero;
     impl_file_age = 0;
-    impl_file_fd = Unix32.create_diskfile "" [Unix.O_RDONLY] 0o666;
+    impl_file_fd = None;
     impl_file_downloaded = Int64.zero;
     impl_file_received = Int64.zero;
     impl_file_last_received = [];
@@ -141,7 +142,7 @@ let dummy_file = as_file dummy_file_impl
 (*                                                                       *)
 (*************************************************************************)
 
-module H = Weak2.Make(struct
+module H = Weak.Make(struct
       type t = file
       let hash file = Hashtbl.hash (file_num file)
       
@@ -252,8 +253,20 @@ let file_best_name (file : file) =
   
 let set_file_best_name file name =
   let file = as_file_impl file in
-  let name = String2.replace name '/' "::" in
-  file.impl_file_best_name <- name
+  let old_name = file.impl_file_best_name in
+  let real_name = Filename2.filesystem_compliant name "" in
+  if real_name = "" then
+    lprintf_nl () "can not rename file \"%s\" to \"%s\""
+      (String.escaped file.impl_file_best_name) (String.escaped real_name)
+  else begin
+    file.impl_file_best_name <- real_name;
+    if name <> real_name then
+      lprintf_nl () "wanted new name \"%s\" changed to \"%s\" due to system limitations"
+        (String.escaped name) (String.escaped file.impl_file_best_name);
+    if !verbose && old_name <> file.impl_file_best_name then
+      lprintf_nl () "best_name of \"%s\" changed to \"%s\""
+        (String.escaped old_name) (String.escaped file.impl_file_best_name)
+  end
 
 let set_file_format (file : file) format =
   let file = as_file_impl file in
@@ -302,8 +315,8 @@ let default_file_print_sources_html file buf =
         let cinfo = client_info c in
         let addr = 
         (match cinfo.GuiTypes.client_kind with
-          Indirect_location (name, _) -> ""
-        | Known_location (ip, port) -> Printf.sprintf "%s:%d" (Ip.to_string ip) port 
+          Indirect_location (_, _, ip, port)
+        | Known_location (ip, port) -> Printf.sprintf "%s:%d" (Ip.to_string ip) port
         )
         in
 
@@ -398,19 +411,20 @@ let add_file_downloaded file n =
 let file_size file = 
   (as_file_impl file).impl_file_size
 
-let file_disk_name file =
-  Unix32.filename (as_file_impl file).impl_file_fd
-
 let file_fd file =
-  (as_file_impl file).impl_file_fd
+  match (as_file_impl file).impl_file_fd with
+    | Some fd -> fd
+    | None -> raise Not_found
+
+let file_disk_name file =
+  Unix32.filename (file_fd file)
 
 let set_file_fd file fd =
-  (as_file_impl file).impl_file_fd <- fd
+  (as_file_impl file).impl_file_fd <- Some fd
 
 let set_file_disk_name file filename =
   let orig_fd = file_fd file in
-  if orig_fd != Unix32.bad_fd then
-    Unix32.rename orig_fd filename
+  Unix32.rename orig_fd filename
 
 let file_downloaded file = (as_file_impl file).impl_file_downloaded
 
@@ -446,7 +460,6 @@ let file_preview (file : file) =
 module G = GuiTypes
 
 let file_downloaders file o cnt =
-  let buf = o.conn_buf in
 
       let srcs = file_active_sources file in
       let counter = ref cnt in
@@ -475,81 +488,67 @@ let file_downloaders file o cnt =
 
 (* Use span for Opera DOM compatibility *)
 let colored_chunks chunks =
-  let ostr = ref "" in
-  let previous = ref 0 in
-  let runlength = ref 0 in
-
-  let missing = ref 0 in
-  let partial = ref 0 in
-  let complete = ref 0 in
-  let verified = ref 0 in
-
-  let chunks_length=Array.length chunks in
-  let rl_divider=
-    if chunks_length > !!html_vd_chunk_graph_max_width then
-       (float_of_int !!html_vd_chunk_graph_max_width) /. (float_of_int chunks_length)
-    else
-      1.
-  in
-
-  let resize n = (int_of_float (floor ((float_of_int n) *. rl_divider))) in
-  let nextbit b =
-    if b = !previous then
-      incr runlength
-    else begin
-      if !runlength > 0 then begin
-        match !!html_vd_chunk_graph_style with
-        | 0 ->
-          let rl_resized = resize !runlength in
-          (* Show only "visible" chunks *)
-          if rl_resized > 0 then
-            ostr := !ostr ^ Printf.sprintf 
-            "\\<span class=\\\"chunk%d\\\" style=\\\"width:%dpx\\\"\\>\\&nbsp;\\</span\\>" !previous rl_resized
-        | 1 | 2 ->
-          (match !previous with
-          | 0 -> missing := !missing + !runlength
-          | 1 -> partial := !partial + !runlength
-          | 2 -> complete := !complete + !runlength
-          | 3 -> verified := !verified + !runlength
-          | _ -> ())
-        | _ -> ();
-      end;
-      previous := b;
-      runlength := 1
+  let chunks_length = Array.length chunks in
+  let graph_width = min !!html_vd_chunk_graph_max_width (8 * chunks_length) in
+  let ostr = Buffer.create 100 in
+  Printf.bprintf ostr "\\<table cellspacing=0 cellpadding=0 width=\\\"%dpx\\\"\\>\\<tr\\>" graph_width;
+  let current_output_bit = ref 0 in
+  let display_bar color length =
+    let resize n = (n * graph_width) / chunks_length in
+    if length > 0 then begin
+      let new_output_bit = !current_output_bit + length in
+      let rl_resized = (resize new_output_bit) - (resize !current_output_bit) in
+      (* Show only "visible" chunks *)
+      if rl_resized > 0 then
+	Printf.bprintf ostr
+	  "\\<td class=\\\"chunk%d\\\" style=\\\"width:%dpx\\\"\\>\\</td\\>" color rl_resized;
+      current_output_bit := new_output_bit
     end in
-  Array.iter (fun b -> nextbit b) chunks;
-  nextbit 99;
-  (match !!html_vd_chunk_graph_style with
-  | 1 ->
-    ostr := !ostr 
-    ^ Printf.sprintf "
-\\<span class=\\\"chunk0\\\" style=\\\"width:%dpx\\\"\\>\\&nbsp;\\</span\\>
-\\<span class=\\\"chunk1\\\" style=\\\"width:%dpx\\\"\\>\\&nbsp;\\</span\\>
-\\<span class=\\\"chunk2\\\" style=\\\"width:%dpx\\\"\\>\\&nbsp;\\</span\\>
-\\<span class=\\\"chunk3\\\" style=\\\"width:%dpx\\\"\\>\\&nbsp;\\</span\\>"
-  (resize !missing) (resize !partial) (resize !complete) (resize !verified)
-  | 2 ->
-    ostr := !ostr 
-    ^ Printf.sprintf "
-\\<span class=\\\"chunk3\\\" style=\\\"width:%dpx\\\"\\>\\&nbsp;\\</span\\>
-\\<span class=\\\"chunk2\\\" style=\\\"width:%dpx\\\"\\>\\&nbsp;\\</span\\>
-\\<span class=\\\"chunk1\\\" style=\\\"width:%dpx\\\"\\>\\&nbsp;\\</span\\>
-\\<span class=\\\"chunk0\\\" style=\\\"width:%dpx\\\"\\>\\&nbsp;\\</span\\>"
-  (resize !verified) (resize !complete) (resize !partial) (resize !missing)
-  | _ -> ());
 
-(*
-  ostr := !ostr 
-  ^ Printf.sprintf 
-  "\\<span class=\\\"chunk0\\\" style=\\\"width:%dpx\\\"\\>\\</span\\>" (resize !missing)
-  ^ Printf.sprintf 
-  "\\<span class=\\\"chunk1\\\" style=\\\"width:%dpx\\\"\\>\\</span\\>" (resize !partial)
-  ^ Printf.sprintf 
-  "\\<span class=\\\"chunk2\\\" style=\\\"width:%dpx\\\"\\>\\</span\\>" (resize !complete)
-  ^ Printf.sprintf 
-  "\\<span class=\\\"chunk3\\\" style=\\\"width:%dpx\\\"\\>\\</span\\>" (resize !verified);
-*)
-  !ostr
+  (match !!html_vd_chunk_graph_style with
+     | 0 ->
+	 let previous = ref 0 in
+	 let runlength = ref 0 in
+
+	 Array.iter (fun b ->
+	   if b = !previous then
+	     incr runlength
+	   else begin
+	     display_bar !previous !runlength;
+	     previous := b;
+	     runlength := 1
+	   end
+	 ) chunks;
+	 display_bar !previous !runlength
+     | _ ->
+	 let missing = ref 0 in
+	 let partial = ref 0 in
+	 let complete = ref 0 in
+	 let verified = ref 0 in
+
+	 Array.iter (fun b -> 
+	   match b with
+             | 0 -> incr missing
+             | 1 -> incr partial
+             | 2 -> incr complete
+             | 3 -> incr verified
+             | _ -> ()
+	 ) chunks;
+	 match !!html_vd_chunk_graph_style with
+	   | 1 ->
+	       display_bar 0 !missing;
+	       display_bar 1 !partial;
+	       display_bar 2 !complete;
+	       display_bar 3 !verified
+	   | 2 ->
+	       display_bar 3 !verified;
+	       display_bar 2 !complete;
+	       display_bar 1 !partial;
+	       display_bar 0 !missing
+	   | _ -> ()
+  );
+  Buffer.add_string ostr "\\</tr\\>\\</table\\>";
+  Buffer.contents ostr
 
 let file_print file o =
   let impl = as_file_impl file in
@@ -557,7 +556,6 @@ let file_print file o =
   let n = impl.impl_file_ops.op_file_network in
   let buf = o.conn_buf in
   let srcs = file_all_sources file in
-  let active_srcs = file_active_sources file in
 
   if use_html_mods o then begin
 
@@ -587,10 +585,29 @@ let file_print file o =
         ("", "sr", Printf.sprintf "%d" (List.length srcs)) ];
 
       Printf.bprintf buf "\\</tr\\>\\<tr class=\\\"dl-1\\\"\\>";
+
       let tt = ref "0=Missing, 1=Partial, 2=Complete, 3=Verified" in
+      let tc = String.length info.G.file_chunks in
+      let c0 = ref 0 in
+      let c1 = ref 0 in
+      let c2 = ref 0 in
+      let c3 = ref 0 in   
+
+      String.iter (fun c ->
+        match c with
+        | '0' -> incr c0
+        | '1' -> incr c1
+        | '2' -> incr c2
+        | '3' -> incr c3
+        | _ -> ()
+      ) info.G.file_chunks;
+      
+      let header = Printf.sprintf "%d (%d+%d+%d+%d): " tc !c0 !c1 !c2 !c3 in
+
       html_mods_td buf [
         (!tt, "sr br", "Chunks");
-        (!tt, "sr", if !!html_vd_chunk_graph then
+        (!tt, "sr", 
+          header ^ if !!html_vd_chunk_graph then
           (colored_chunks (Array.init (String.length info.G.file_chunks)
           (fun i -> ((int_of_char info.G.file_chunks.[i])-48))))
           else
@@ -628,7 +645,6 @@ let file_print file o =
             file_print_sources_html file buf
           else begin
             Printf.bprintf buf "%d sources:\n" (List.length srcs);
-          let counter = ref 0 in
           let print_source c =
                   Printf.bprintf buf "  [%4d] " (client_num c);
                   client_bprint c buf;
@@ -842,8 +858,15 @@ let check_file_implementations () =
 let _ =
   Heap.add_memstat "CommonFile" (fun level buf ->
       let counter = ref 0 in
-      H.iter (fun _ -> incr counter) files_by_num;
+      H.iter (fun f -> incr counter;
+       if level > 0 then
+         Printf.bprintf buf "%d sources: %s: %s \n" 
+          (List.length (file_all_sources f)) 
+          (file_network f).network_name
+          (file_best_name f);
+      ) files_by_num;
       Printf.bprintf buf "  files: %d\n" !counter;
+      Printf.bprintf buf "  files_ops: %d\n" (List.length !files_ops);
   )
 
 
@@ -897,7 +920,7 @@ let file_verify file key begin_pos end_pos =
     result
   with
     | Not_found -> raise Not_found
-    | _ -> if !verbose_md4 then lprintf_nl () "Checksum computed: chunk MISSING";
+    | e -> lprintf_nl () "Checksum computation failed: Exception: %s" (Printexc2.to_string e);
     false
 
 let file_mtime file = Unix32.mtime64 (file_fd file)
@@ -946,6 +969,8 @@ let propose_filename file =
 let propose_filenames () =
   H.iter (fun file -> propose_filename file)  files_by_num
 
+let forceable_download = ref []
+
 (*************************************************************************)
 (*                                                                       *)
 (*                         Protect globals                               *)
@@ -954,3 +979,32 @@ let propose_filenames () =
 
 let com_files_by_num = files_by_num
 let files_by_num = ()
+
+let impl_file_info impl =
+  let module T = GuiTypes in
+  {
+    T.file_fields = T.Fields_file_info.all;
+    T.file_comment = impl.impl_file_comment;
+    T.file_name = impl.impl_file_best_name;
+    T.file_num = impl.impl_file_num;
+    T.file_size = impl.impl_file_size;
+    T.file_downloaded = impl.impl_file_downloaded;
+    T.file_state = impl.impl_file_state;
+    T.file_download_rate = file_download_rate impl;
+    T.file_priority = impl.impl_file_priority;
+    T.file_age = impl.impl_file_age;
+    T.file_last_seen = impl.impl_file_last_seen;
+
+    T.file_network = 0;
+    T.file_names = [];
+    T.file_md4 = Md4.null;
+    T.file_all_sources = 0;
+    T.file_active_sources = 0;
+    T.file_sources = None;
+    T.file_chunks = "";
+    T.file_availability = [];
+    T.file_format = FormatNotComputed 0;
+    T.file_chunks_age = [||];
+    T.file_uids = [];
+    T.file_sub_files = [];
+  }
