@@ -27,7 +27,7 @@ type 'a file_impl = {
   mutable impl_file_ops : 'a file_ops;
   mutable impl_file_size : int64;
   mutable impl_file_age : int;
-  mutable impl_file_fd : Unix32.t;
+  mutable impl_file_fd : Unix32.t option;
   mutable impl_file_downloaded : int64;
   mutable impl_file_received : int64;
   mutable impl_file_last_received : (int64 * int) list;
@@ -126,4 +126,7 @@ val file_mtime : CommonTypes.file -> float
   CommonTypes.file -> CommonTypes.file -> int64 -> int64 -> int64 -> unit
 val file_files : CommonTypes.file -> CommonTypes.file list
 val propose_filenames : unit -> unit
-val propose_filename : CommonTypes.file -> unit
\ No newline at end of file
+val propose_filename : CommonTypes.file -> unit
+
+val forceable_download : CommonTypes.result_info list ref
+val impl_file_info : 'a file_impl -> GuiTypes.file_info
