@@ -17,6 +17,7 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *)
 
+open Int64ops
 open Printf2
 open CommonTypes
 
@@ -26,21 +27,19 @@ let input_int8 ic =
 let input_int16 ic =
   let i0 = input_int8  ic in
   let i1 = input_int8 ic in
-  i0 + 256 * i1
+  i0 lor (i1 lsl 8)
 
-let int32_65536 = Int64.of_int 65536
-  
 let input_int32 ic =
   let i0 = input_int16 ic in
   let i1 = input_int16 ic in
   let i0 = Int64.of_int i0 in
   let i1 = Int64.of_int i1 in
-  Int64.add i0 (Int64.mul i1 int32_65536)
+  or64 i0 (left64 i1 16)
   
 let input_int ic =
   let i0 = input_int16 ic in
   let i1 = input_int16 ic in
-  i0 + i1 * 65536
+  i0 lor (i1 lsl 16)
 
 let input_string4 ic =
   let s = String.create 4 in
@@ -52,7 +51,7 @@ let print_string4 v s =
   for i = 0 to 3 do
     let c = s.[i] in
     let int = int_of_char c in
-    if int > 31 && int <127 then
+    if int > 31 && int < 127 then
       lprint_char c
     else lprintf "[%d]" int
   done;
@@ -200,8 +199,6 @@ let get_audio_codec s =
   ) s;
   try
     let n = int_of_string !str in
-    Printf.printf "get_audio_codec: %d [%s]\n" n !str;
-    flush stdout;
     match n with
       1 -> "pcm"
     | 55 -> "mp3"
@@ -272,14 +269,13 @@ let normalize_stream_type s ct =
 let rec next_ogg_stream ic ogg_infos str stream_number =
   let pos = pos_in ic in
   page_seek ic str pos;
-  let header_start_pos = (pos_in ic - 4) in
   let pos = pos_in ic in
 (*
   let serial_number = String.create 4 in
   seek_in ic (pos+10);
   really_input ic serial_number 0 4;
   let stream_number = read32 serial_number in
-  Printf.printf "Stream Serial Number: %0.f\n" stream_number;
+  lprintf "Stream Serial Number: %0.f\n" stream_number;
 *)
   seek_in ic (pos+24);
   let content_type = String.create 1 in
@@ -306,12 +302,7 @@ and get_ogg_video_info  ic ogg_infos str sizeof_packet stream_number =
   let s = String.create sizeof_packet in
   really_input ic s 0 sizeof_packet;
   let codec = String.lowercase (String.sub s 0 4) in
-  let size = read32 (String.sub s 4 4) in
   let time_unit = read64 (String.sub s 8 8) in
-  let sample_per_unit = read64 (String.sub s 16 8) in
-  let default_len = read32 (String.sub s 24 4) in
-  let buffer_size = read32 (String.sub s 28 4) in
-  let bits_per_sample = read16 (String.sub s 32 2) in
   let video_width =
     if sizeof_packet >= sizeof_old_ogm_packet
       then read32 (String.sub s 36 4)
@@ -338,12 +329,7 @@ and get_ogg_audio_info  ic ogg_infos str sizeof_packet stream_number =
   let s = String.create sizeof_packet in
   really_input ic s 0 sizeof_packet;
   let codec = get_audio_codec (String.sub s 0 4) in
-  let size = read32 (String.sub s 4 4) in
-  let time_unit = read64 (String.sub s 8 8) in
   let sample_per_unit = read64 (String.sub s 16 8) in
-  let default_len = read32 (String.sub s 24 4) in
-  let buffer_size = read32 (String.sub s 28 4) in
-  let bits_per_sample = read16 (String.sub s 32 2) in
   let channels =
     if sizeof_packet >= sizeof_old_ogm_packet
       then read16 (String.sub s 36 2)
@@ -410,13 +396,9 @@ and get_ogg_theora_info  ic ogg_infos str stream_number =
   let vrev = int_of_char s.[2] in
   let codec = Printf.sprintf "theora-%d.%d.%d" vmaj vmin vrev in
   (* multiply by 16 to get the actual frame width in pixels *)
-  let fmbw = read16B (String.sub s 3 2) lsl 4 in
   (* multiply by 16 to get the actual frame height in pixels *)
-  let fmbh = read16B (String.sub s 5 2) lsl 4 in
   let picw = read24B (String.sub s 7 3)  in
   let pich = read24B (String.sub s 10 3) in
-  let picx = int_of_char s.[13] in
-  let picy = int_of_char s.[14] in
   let frn = read32B (String.sub s 15 4) in
   let frd = read32B (String.sub s 19 4) in
   let sample_rate = frn /. frd in
@@ -538,37 +520,10 @@ let search_info_avi ic =
                 
                 ignore (input_string4 ic);
                 
-                
-                let dwMicroSecPerFrame = input_int32 ic in
-                let dwMaxBytesPerSec = input_int32 ic in
-                let dwPaddingGranularity = input_int32 ic in
-                let dwFlags = input_int32 ic in
-                let dwTotalFrames = input_int32 ic in
-                let dwInitialFrames = input_int32 ic in
-                let dwStreams = input_int32 ic in
-                let dwSuggestedBufferSize = input_int32 ic in              
-                let dwWidth = input_int32 ic in
-                let dwHeight = input_int32 ic in
-
-(*
-              print_int32 "dwMicroSecPerFrame" dwMicroSecPerFrame ;
-              print_int32 "dwMaxBytesPerSec" dwMaxBytesPerSec ;
-              print_int32 "dwPaddingGranularity" dwPaddingGranularity ;
-              print_int32 "dwFlags" dwFlags ;
-              print_int32 "dwTotalFrames" dwTotalFrames ;
-              print_int32 "dwInitialFrames" dwInitialFrames ;
-              print_int32 "dwStreams" dwStreams ;
-              print_int32 "dwSuggestedBufferSize" dwSuggestedBufferSize ;
-              print_int32 "dwWidth" dwWidth;
-              print_int32 "dwHeight" dwHeight;
-              *)
-                
-                seek_in ic ((Int64.to_int pos) + main_header_len +20);
-                let s = input_string4 ic in
-(*              lprint_string4 "LIST:" s; *)
-                let pos_in = Int64.add pos (Int64.of_int (
-                      main_header_len +24)) in
-                let last_pos = Int64.add pos_in size2 in
+                seek_in ic ((Int64.to_int pos) + main_header_len + 20);
+                let pos_in = 
+                  pos ++ Int64.of_int (main_header_len + 24) in
+                let last_pos = pos_in ++ size2 in
                 iter_list pos_in last_pos
             
             
@@ -579,9 +534,9 @@ let search_info_avi ic =
             | "strl" ->
 (*              lprintf "STREAM DESCRIPTION\n";  *)
                 
-                let offset = Int64.of_int 4  in
-                let pos0 = Int64.add pos offset in
-                let end_pos0 = Int64.add pos size2 in
+                let offset = 4L  in
+                let pos0 = pos ++ offset in
+                let end_pos0 = pos ++ size2 in
                 iter_list pos0 end_pos0
             
             | "strh" ->
@@ -639,12 +594,12 @@ let search_info_avi ic =
             | _ -> ()
           end;
           
-          iter_list (Int64.add pos (Int64.add size2 (Int64.of_int 8))) end_pos
+          iter_list (pos ++ size2 ++ 8L) end_pos
         end 
     
     in
-    let pos0 = Int64.of_int 16 in
-    iter_list pos0 (Int64.add pos0 size);
+    let pos0 = 16L in
+    iter_list pos0 (pos0 ++ size);
 (*  lprintf "DONE\n";  *)
     ()
   with
