@@ -26,6 +26,8 @@ open Options
 open Unix
 
 
+let startup_message = ref ""
+
 let bin_dir = Filename.dirname Sys.argv.(0)
 
 let hidden_dir_prefix =
@@ -106,15 +108,27 @@ If you are using a chroot environment, create it inside the chroot.\n" file
 
 let _ =
   lprintf_nl "Starting MLDonkey %s ... " Autoconf.current_version;
+  let ulof_old = Unix2.c_getdtablesize () in
   lprintf_nl "Language %s, locale %s, ulimit for open files %d"
-    Charset.default_language Charset.locstr (Unix2.c_getdtablesize ());
-  lprintf_nl "MLDonkey is working in %s" file_basedir;
+    Charset.default_language Charset.locstr ulof_old;
 
+  let nofile = Unix2.ml_getrlimit Unix2.RLIMIT_NOFILE in
+    if nofile.Unix2.rlim_max > 0 && nofile.Unix2.rlim_max > nofile.Unix2.rlim_cur then
+      Unix2.ml_setrlimit Unix2.RLIMIT_NOFILE nofile.Unix2.rlim_max;
   let ulof = Unix2.c_getdtablesize () in
+  if ulof_old <> ulof then
+    lprintf_nl "raised ulimit for open files from %d to %d" ulof_old ulof;
   if ulof < 150 then begin
     lprintf_nl "ulimit for open files is set to %d, at least 150 is required, exiting..." ulof;
     exit 2
   end;
+
+  lprintf_nl "MLDonkey is working in %s" file_basedir;
+  if not (Sys.file_exists file_basedir) then begin
+    lprint_newline ();
+    lprintf_nl "creating new MLDonkey base directory in %s\n" file_basedir;
+    startup_message := (Printf.sprintf "MLDonkey created a new home directory in %s\n" file_basedir)
+  end;
   (try
      Unix2.safe_mkdir file_basedir
    with e ->
@@ -123,9 +137,23 @@ let _ =
      exit 2);
   Unix2.can_write_to_directory file_basedir;
   Unix.chdir file_basedir;
+  
+  let uname = Unix32.uname () in
+  if uname = "" then
+    begin
+      lprintf_nl "Unknown operating system, please report to the MLDonkey development team";
+      lprintf_nl "at http://savannah.nongnu.org/bugs/?group=mldonkey"
+    end
+  else
+    if not (Unix32.os_supported ()) then begin
+      lprintf_nl "WARNING: MLDonkey is not suuported on %s" uname;
+      if Autoconf.windows then
+        lprintf_nl "WARNING: MLDonkey is only supported on Windows NT/2000/XP/Server 2003."
+    end;
 
   if (String2.starts_with (Filename.basename Sys.argv.(0)) "mlnet")
-    && not Autoconf.windows && not (Autoconf.system = "morphos") && not (Sys.file_exists "/dev/urandom") then begin
+    && not Autoconf.windows && not (Autoconf.system = "morphos") &&
+       Autoconf.donkey_sui = "yes" && not (Sys.file_exists "/dev/urandom") then begin
       lprintf "%s" (exit_message_dev "urandom");
       if Autoconf.system = "hpux" then
         lprintf_nl "For HP-UX get urandom support from http://www.josvisser.nl/hpux11-random";
@@ -453,7 +481,6 @@ let verbosity = define_expert_option current_section ["verbosity"]
   hs : http_server messages
   act : debug activity
   bw : debug bandwidth
-  redir : debug redirector
   unexp : debug unexpected messages
 "
     string_option ""
@@ -885,28 +912,6 @@ let socket_keepalive = define_expert_option current_section ["socket_keepalive"]
   This implies some bandwidth-cost (with 200 connections ~10-20%)"
     bool_option !BasicSocket.socket_keepalive
 
-let network_update_url =
-  define_expert_option current_section ["network_update_url"]
-    "URL where mldonkey can download update information on the network"
-    string_option ""
-
-let enable_mlnet_redirector =
-  define_option current_section ["enable_mlnet_redirector"]
-    "Enable the mlnet redirector"
-    bool_option true
-
-let mlnet_redirector = define_expert_option current_section ["redirector"]
-    "IP:port of the network redirector"
-    addr_option ("129.104.11.42", 3999)
-
-(* The former redirector is dead, so use a new one. *)
-let _ =
-  option_hook mlnet_redirector (fun _ ->
-      let (ip, port) = !!mlnet_redirector in
-      if ip = "128.93.52.5" then
-        mlnet_redirector =:=  ("129.104.11.42", 3999)
-  )
-
 let http_proxy_server = define_option current_section ["http_proxy_server"]
     "Direct HTTP queries to HTTP proxy" string_option ""
 let http_proxy_port = define_option current_section ["http_proxy_port"]
@@ -1066,12 +1071,6 @@ let config_files_security_space = define_expert_option current_section
   "How many megabytes should MLdonkey keep for saving configuration files."
     int_option 10
 
-let propagate_servers = define_expert_option current_section ["propagate_servers"]
-  "Send an UDP packet to a central servers with the list of servers you
-  are currently connected to, for the central server to be able to
-    generate accurate server lists." bool_option false
-
-
 
 
 (*************************************************************************)
@@ -1133,6 +1132,11 @@ let allow_any_command = define_option current_section
 ones in allowed_commands"
     bool_option false
 
+let enable_user_config = define_option current_section
+    ["enable_user_config"]
+  "Are all users allowed to change MLDonkey options?"
+    bool_option true
+
 let allow_browse_share = define_option current_section ["allow_browse_share"]
   "Allow others to browse our share list (0: none, 1: friends only, 2: everyone" allow_browse_share_option 1
 
@@ -1308,7 +1312,7 @@ let commands_frame_height = define_expert_option current_section ["commands_fram
 
 let motd_html = define_expert_option current_section ["motd_html"]
     "Message printed at startup (automatically downloaded from the previous
-    URL directory" string_option "<br><div align=\"center\"><h3>Welcome to MLdonkey</h3></div>"
+    URL directory" string_option "<br><div align=\"center\"><h3>Welcome to MLDonkey</h3></div>"
 
 let compaction_delay = define_expert_option current_section ["compaction_delay"]
     "Force compaction every <n> hours (in [1..24])"
@@ -1653,10 +1657,6 @@ let _ =
   option_hook packet_frame_size (fun _ ->
       TcpBufferedSocket.packet_frame_size := !!packet_frame_size
   );
-  option_hook network_update_url (fun _ ->
-      if !!network_update_url =
-        "http://savannah.nongnu.org/download/mldonkey/network/" then
-        network_update_url =:= "");
   option_hook minor_heap_size (fun _ ->
       let gc_control = Gc.get () in
       Gc.set { gc_control with Gc.minor_heap_size =
@@ -1689,7 +1689,6 @@ let verbose_udp = ref false
 let verbose_supernode = ref false
 let verbose_swarming = ref false
 let verbose_activity = ref false
-let verbose_redirector = ref false
 let verbose_unexpected_messages = ref false
 
 let set_all v =
@@ -1717,7 +1716,6 @@ let set_all v =
   Http_client.verbose := v;
   Http_server.verbose := v;
   verbose_activity := v;
-  verbose_redirector := v;
   verbose_unexpected_messages := v
 
 let _ =
@@ -1751,7 +1749,6 @@ let _ =
           | "hs" -> Http_server.verbose := true
           | "act" -> verbose_activity := true
           | "bw" -> incr BasicSocket.verbose_bandwidth
-          | "redir" -> verbose_redirector := true
           | "unexp" -> verbose_unexpected_messages := true
 
           | "all" ->
