@@ -79,6 +79,22 @@ let get_string s pos =
 let get_string_bin s pos =
   get_string s pos
     
+let get_ip2 proto s pos =
+  let ip,pos = get_ip s pos,(pos+4) in 
+  if proto > 37 then
+    let _ = get_uint8 s pos in 
+    ip,(pos+1)
+  else
+   ip,pos
+
+let get_hostname proto s pos =
+  let hn,pos = get_string s pos in
+  if proto > 37 then
+    let _ = get_uint8 s pos in
+    hn,(pos+1)
+  else
+    hn,pos
+    
 let get_list f s pos =
   let len = get_int16 s pos in
   let rec iter n pos =
@@ -89,11 +105,24 @@ let get_list f s pos =
   in
   iter len (pos+2)
 
+let get_list2 proto f s pos =
+  let len = get_int16 s pos in
+  let rec iter n pos =
+    if n = 0 then [],pos else
+    let head, pos = f proto s pos in
+    let tail, pos = iter (n-1) pos in
+    head :: tail, pos
+  in
+  iter len (pos+2)
+
 let get_array f s pos = 
   let list, pos = get_list f s pos in
   Array.of_list list, pos
 
 let get_bool s pos = (get_uint8 s pos) = 1
+let get_bool_option s pos = 
+  let i = get_uint8 s pos in
+  if i = 2 then None else Some (i = 1)
 
 let get_float s pos = 
   let s, pos = get_string s pos in
@@ -369,7 +398,7 @@ let get_tag_name s pos =
   let tag_name = field_of_string name in
   tag_name, pos
   
-let get_tag s pos =
+let get_tag proto s pos =
   let tag_name, pos = get_tag_name s pos in
   let value, pos =
     match get_uint8 s pos with
@@ -379,7 +408,8 @@ let get_tag s pos =
         Fint64 (get_uint64_32 s (pos+1)), pos+5
     | 2 -> let s, pos = get_string s (pos+1) in
         String s, pos
-    | 3 -> Addr (get_ip s (pos+1)), pos+5
+    | 3 -> let ip, pos = get_ip2 proto s (pos+1) in
+        Addr ip, pos
     | 4 -> Uint16 (get_int16 s (pos+1)), pos+3
     | 5 -> Uint8 (get_uint8 s (pos+1)), pos+2
     | 6 -> Pair (get_uint64_32 s (pos+1), get_uint64_32 s (pos+5)), pos+9
@@ -389,7 +419,7 @@ let get_tag s pos =
 
 let get_result proto s pos =
   let num  = get_int s pos in
-  let net = get_int s (pos+4) in
+(*  let net = get_int s (pos+4) in *)
   let names, pos = get_list get_string s (pos+8) in
   let uids, pos = 
     if proto < 27 then
@@ -400,7 +430,7 @@ let get_result proto s pos =
   let size, pos = get_uint64_2 proto s pos in
   let format, pos = get_string s pos in
   let t, pos = get_string s pos in
-  let tags, pos = get_list get_tag s pos in
+  let tags, pos = get_list2 proto get_tag s pos in
   let comment, pos = get_string s pos in
   let already_done = get_bool  s pos in
   let time, pos = 
@@ -421,6 +451,7 @@ let get_result proto s pos =
     result_comment = comment;
     result_done = already_done;
     result_modified = false;
+    result_force = false;
     result_time = time;
   }, pos+1
 
@@ -474,6 +505,13 @@ let get_int_date proto s pos =
 let get_int_pos s pos =
   get_int s pos, pos + 4
   
+let get_sub_files s pos =
+  get_list (fun s pos ->
+    let name, pos = get_string s pos in
+    let size, pos = get_int64 s pos, pos+8 in
+    (name, size), pos
+  ) s pos
+  
 let get_file proto s pos = 
   let num = get_int s pos in
   let net = get_int s (pos+4) in
@@ -517,6 +555,12 @@ let get_file proto s pos =
     else
       get_list get_uid s pos
   in
+  let sub_files, pos =
+    if proto > 35 then
+      get_sub_files s pos
+    else [], pos
+  in
+
   (*
   assert (num = file_info_test.file_num);
   assert (net = file_info_test.file_network);
@@ -561,6 +605,7 @@ let get_file proto s pos =
     file_last_seen = last_seen;
     file_priority = priority;
     file_uids = uids;
+    file_sub_files = sub_files;
   }, pos
 
 let get_host_state proto s pos =
@@ -602,10 +647,10 @@ let get_addr proto s pos =
   let addr, pos =
   match get_uint8 s pos with
     0 ->
-      let ip = get_ip s (pos+1) in
-      Ip.addr_of_ip ip, pos+5
+      let ip, pos = get_ip2 proto s (pos+1) in
+      Ip.addr_of_ip ip, pos
   | 1 ->
-      let name,pos = get_string s (pos+1) in
+      let name,pos = get_hostname proto s (pos+1) in
       Ip.addr_of_string name, pos
   | _ -> assert false
   in
@@ -625,13 +670,26 @@ let get_server proto s pos =
   in
   let port = get_int16 s pos in
   let score = get_int s (pos+2) in
-  let tags, pos = get_list get_tag s (pos+6) in
+  let tags, pos = get_list2 proto get_tag s (pos+6) in
   let nusers, pos = get_int64_28 proto s pos in
   let nfiles, pos = get_int64_28 proto s pos in
   let state, pos = get_host_state proto s pos in
   let name, pos = get_string s pos in
   let description, pos = get_string s pos in
   let preferred = if proto > 28 then get_bool s pos else false in
+  let pos=pos+1 in
+  let ve,ma,lo,so,ha,pi,pos = 
+    if proto > 39 then
+      let ve,pos = get_string s pos in
+      let ma,pos = get_int64 s pos, (pos+8) in
+      let lo,pos = get_int64 s pos, (pos+8) in
+      let so,pos = get_int64 s pos, (pos+8) in
+      let ha,pos = get_int64 s pos, (pos+8) in
+      let pi,pos = get_int s pos, (pos+4) in
+      ve,ma,lo,so,ha,pi,pos
+    else
+      "",0L,0L,0L,0L,0,pos
+  in
   {
     server_num = num;
     server_network = net;
@@ -648,6 +706,12 @@ let get_server proto s pos =
     server_banner = "";
     server_users = None;
     server_preferred = preferred;
+    server_version = ve; 
+    server_max_users = ma;
+    server_lowid_users = lo;
+    server_soft_limit = so;
+    server_hard_limit = ha;
+    server_ping = pi;
   }, pos
 
 let get_client_type s pos = 
@@ -657,26 +721,34 @@ let get_client_type s pos =
   | 2 -> client_contact_tag
   | _ -> assert false
 
-let get_kind s pos =
+let get_kind proto s pos =
   match get_uint8 s pos with
     0 ->
-      let ip = get_ip s (pos+1) in
-      let port = get_int16 s (pos+5) in
-      Known_location (ip, port), pos+7
+      let ip,pos = get_ip2 proto s (pos+1) in
+      let port = get_int16 s pos in
+      Known_location (ip, port), pos+2
   | 1 ->
-      let name, pos = get_string s (pos+1) in
+      let name, pos = get_hostname proto s (pos+1) in
       let md4 = get_md4 s pos in
-      Indirect_location (name, md4), pos+16
+      let ip, port, pos = 
+        if proto > 38 then begin
+          let myip , pos = get_ip2 proto s (pos+16) in
+          let myport = get_int16 s pos in
+          myip, myport, (pos+2)
+        end else
+          Ip.null, 0, (pos+16)
+      in  
+      Indirect_location (name, md4, ip, port), pos
   | _ -> assert false
 
 let get_client proto s pos =
   if proto <= 18 then
     let num = get_int s pos in
     let net = get_int s (pos+4) in
-    let kind, pos = get_kind s (pos+8) in
+    let kind, pos = get_kind proto s (pos+8) in
     let state,pos = get_host_state proto s pos in
     let t = get_client_type s pos in
-    let tags, pos = get_list get_tag s (pos+1) in
+    let tags, pos = get_list2 proto get_tag s (pos+1) in
     let name, pos = get_string s pos in
     let rating = get_int s pos in
     let chat_port = get_int s (pos+4) in
@@ -698,15 +770,16 @@ let get_client proto s pos =
       client_downloaded = zero;
       client_uploaded = zero;
       client_upload = None;
+      client_sui_verified = None;
 (*      client_sock_addr = ""; *)
     }, pos+8
   else
   let num = get_int s pos in
   let net = get_int s (pos+4) in
-  let kind, pos = get_kind s (pos+8) in
+  let kind, pos = get_kind proto s (pos+8) in
   let state,pos = get_host_state proto s pos in
   let t = get_client_type s pos in
-  let tags, pos = get_list get_tag s (pos+1) in
+  let tags, pos = get_list2 proto get_tag s (pos+1) in
   let name, pos = get_string s pos in
   let rating = get_int s pos in
   let software, pos = get_string s (pos+4) in
@@ -732,6 +805,11 @@ let get_client proto s pos =
      if proto >= 33 then
        get_string s pos
        else "", pos
+   in 
+   let verified =
+     if proto >= 35 then
+       get_bool_option s pos
+       else None
    in  {
     client_num = num;
     client_network = net;
@@ -750,6 +828,7 @@ let get_client proto s pos =
     client_downloaded = downloaded;
     client_uploaded = uploaded;
     client_upload = upload;
+    client_sui_verified = verified;
 (*    client_sock_addr = sock_addr; *)
   }, pos
 
@@ -800,13 +879,13 @@ let get_network proto s pos =
   }, pos
 
 
-let get_user s pos =
+let get_user proto s pos =
   let num = get_int s pos in
   let md4 = get_md4 s (pos+4) in
   let name, pos = get_string s (pos+20) in
-  let ip = get_ip s pos in
-  let port = get_int16 s (pos+4) in
-  let tags, pos = get_list get_tag s (pos+6) in
+  let ip, pos = get_ip2 proto s pos in
+  let port = get_int16 s pos in
+  let tags, pos = get_list2 proto get_tag s (pos+6) in
   let server = get_int s pos in
   {
     user_num = num;
@@ -857,6 +936,7 @@ let get_shared_info proto s pos =
     shared_uploaded = uploaded;
     shared_requests = requests;
     shared_uids = [];
+    shared_sub_files = [];
   }
 
 let get_shared_info_version_10 proto s pos =
@@ -872,6 +952,11 @@ let get_shared_info_version_10 proto s pos =
     else
       get_list get_uid s (pos+12)
   in
+  let sub_files, pos =
+    if proto > 36 then
+      get_sub_files s pos
+    else [], pos
+  in
   {
     shared_num = num;
     shared_network = network;
@@ -880,6 +965,7 @@ let get_shared_info_version_10 proto s pos =
     shared_uploaded = uploaded;
     shared_requests = requests;
     shared_uids = uids;
+    shared_sub_files = sub_files;
   }
 
 
@@ -894,7 +980,7 @@ let from_gui (proto : int array) opcode s =
 
     let proto = if opcode > from_gui_last_opcode then 0 else proto.(opcode) in
     if !verbose_gui_decoding then
-      lprintf_nl "FROM GUI: Opcode %d" opcode; 
+      lprintf_nl "[gDe] FROM_GUI: Opcode %d %s" opcode (String.escaped s);
     match opcode with
       0 -> GuiProtocol (get_int s 2)
 
@@ -927,7 +1013,7 @@ let from_gui (proto : int array) opcode s =
         Download_query (list, result_num, false)
 
     | 8 -> let string, pos = get_string s 2 in
-        lprintf_nl "Received string: [%s]" (String.escaped string);
+        lprintf_nl "[gDe] Received string: [%s]" (String.escaped string);
         Url string 
 
     | 9 -> let int = get_int s 2 in RemoveServer_query int
@@ -1207,7 +1293,7 @@ let to_gui (proto : int array)  opcode s =
     let proto = if opcode > to_gui_last_opcode then 0 else proto.(opcode) in
     
     if !verbose_gui_decoding then
-      lprintf_nl "TO GUI: Opcode %d" opcode;
+      lprintf_nl "[gDe] TO GUI: Opcode %d" opcode;
     match opcode with
     | 0 ->
         let version = get_int s 2 in
@@ -1322,7 +1408,7 @@ let to_gui (proto : int array)  opcode s =
         Network_info network_info
     
     | 21 ->
-        let user_info, pos = get_user  s 2 in
+        let user_info, pos = get_user proto s 2 in
         User_info user_info
     
     | 22 ->
