@@ -25,7 +25,6 @@ open CommonNetwork
 open CommonSearch
 open CommonTypes
 open CommonGlobals
-open CommonGraphics
 open CommonShared
 open GuiTypes
 open CommonComplexOptions
@@ -33,6 +32,7 @@ open CommonFile
 open Options
 open BasicSocket
 open TcpBufferedSocket
+open DriverGraphics
 open DriverInteractive
 open CommonOptions
 
@@ -133,7 +133,7 @@ let eval auth cmd o =
                 ("", "sr", "\\<a href=\\\"submit?q=" ^ !ncmd ^
                   "\\\"\\>" ^ !ncmd ^ "\\</a\\>");
                 ("", "srw", Str.global_replace (Str.regexp "\n") "\\<br\\>" !nhelp);
-                ("", "sr", "\\<a href=\\\"http://mldonkey.berlios.de/modules.php?name=Wiki&pagename=" ^ !ncmd ^
+                ("", "sr", "\\<a href=\\\"http://mldonkey.sourceforge.net/" ^ (String2.upp_initial !ncmd) ^
                   "\\\"\\>wiki\\</a\\>"); ];
               Printf.bprintf buf "\\</tr\\>\n";
           )
@@ -601,10 +601,11 @@ let telnet_handler t event =
 
         before_telnet_output o sock;
         TcpBufferedSocket.write_string sock
-	   (Printf.sprintf "Welcome to MLDonkey %s" Autoconf.current_version);
+	   (Printf.sprintf "Welcome to MLDonkey %s\n" Autoconf.current_version);
+        TcpBufferedSocket.write_string sock (DriverInteractive.real_startup_message ());
 
         TcpBufferedSocket.write_string sock (dollar_escape o false
-            "\n$cWelcome on mldonkey command-line$n\n\nUse $r?$n for help\n\n");
+            "$cWelcome on mldonkey command-line$n\n\nUse $r?$n for help\n\n");
 
         after_telnet_output o sock
 	end
@@ -1146,107 +1147,109 @@ let http_handler o t r =
         | "oneframe.html" ->
             html_open_page buf t r true;
             Buffer.add_string buf !!motd_html;
-	    Buffer.add_string buf "<p><pre>";
-	    ignore (CommonComplexOptions.buildinfo false buf);
+	    Buffer.add_string buf "<p><pre><b><h3>";
+            Buffer.add_string buf (DriverInteractive.real_startup_message ());
+	    Buffer.add_string buf "</b></h3>";
+	    ignore (buildinfo false buf);
 	    Buffer.add_string buf "\n";
-	    ignore (CommonComplexOptions.runinfo false buf);
+	    ignore (runinfo false buf o);
 	    Buffer.add_string buf "</pre>\n"
 
         | "bw_updown.png" ->
             (match http_error_no_gd "png" with
               false ->
-                do_draw_pic "Traffic" "s(kb)" "t(h:m:s)" download_history upload_history;
+                G.do_draw_pic "Traffic" "s(kb)" "t(h:m:s)" download_history upload_history;
                 http_send_bin r buf "bw_updown.png"
             | true -> raise Not_found)
 
         | "bw_updown.jpg" ->
             (match http_error_no_gd "jpg" with
               false ->
-                do_draw_pic "Traffic" "s(kb)" "t(h:m:s)" download_history upload_history;
+                G.do_draw_pic "Traffic" "s(kb)" "t(h:m:s)" download_history upload_history;
                 http_send_bin r buf "bw_updown.jpg"
             | true -> raise Not_found)
 
         | "bw_download.png" ->
             (match http_error_no_gd "png" with
               false ->
-                do_draw_down_pic "Traffic" "download" "s(kb)" "t(h:m:s)" download_history;
+                G.do_draw_down_pic "Traffic" "download" "s(kb)" "t(h:m:s)" download_history;
                 http_send_bin r buf "bw_download.png"
             | true -> raise Not_found)
 
         | "bw_download.jpg" ->
             (match http_error_no_gd "jpg" with
               false ->
-                do_draw_down_pic "Traffic" "download" "s(kb)" "t(h:m:s)" download_history;
+                G.do_draw_down_pic "Traffic" "download" "s(kb)" "t(h:m:s)" download_history;
                 http_send_bin r buf "bw_download.jpg"
             | true -> raise Not_found)
 
         | "bw_upload.png" ->
             (match http_error_no_gd "png" with
               false ->
-                do_draw_up_pic "Traffic" "upload" "s(kb)" "t(h:m:s)" upload_history;
+                G.do_draw_up_pic "Traffic" "upload" "s(kb)" "t(h:m:s)" upload_history;
                 http_send_bin r buf "bw_upload.png"
             | true -> raise Not_found)
 
         | "bw_upload.jpg" ->
             (match http_error_no_gd "jpg" with
             | false ->
-                do_draw_up_pic "Traffic" "upload" "s(kb)" "t(h:m:s)" upload_history;
+                G.do_draw_up_pic "Traffic" "upload" "s(kb)" "t(h:m:s)" upload_history;
                 http_send_bin r buf "bw_upload.jpg"
             | true -> raise Not_found)
 
         | "bw_h_updown.png" ->
             (match http_error_no_gd "png" with
             | false ->
-                do_draw_h_pic "Traffic" "s(kb)" "t(h:m:s)" download_h_history upload_h_history;
+                G.do_draw_h_pic "Traffic" "s(kb)" "t(h:m:s)" download_h_history upload_h_history;
                 http_send_bin r buf "bw_h_updown.png"
             | true -> raise Not_found)
 
         | "bw_h_updown.jpg" ->
             (match http_error_no_gd "jpg" with
             | false ->
-                do_draw_h_pic "Traffic" "s(kb)" "t(h:m:s)" download_h_history upload_h_history;
+                G.do_draw_h_pic "Traffic" "s(kb)" "t(h:m:s)" download_h_history upload_h_history;
                 http_send_bin r buf "bw_h_updown.jpg"
             | true -> raise Not_found)
 
         | "bw_h_download.png" ->
             (match http_error_no_gd "png" with
             | false ->
-                do_draw_down_h_pic "Traffic" "download" "s(kb)" "t(h:m:s)" download_h_history;
+                G.do_draw_down_h_pic "Traffic" "download" "s(kb)" "t(h:m:s)" download_h_history;
                 http_send_bin r buf "bw_h_download.png"
             | true -> raise Not_found)
 
         | "bw_h_download.jpg" ->
             (match http_error_no_gd "jpg" with
             | false ->
-                do_draw_down_h_pic "Traffic" "download" "s(kb)" "t(h:m:s)" download_h_history;
+                G.do_draw_down_h_pic "Traffic" "download" "s(kb)" "t(h:m:s)" download_h_history;
                 http_send_bin r buf "bw_h_download.jpg"
             | true -> raise Not_found)
 
         | "bw_h_upload.png" ->
             (match http_error_no_gd "png" with
             | false ->
-                do_draw_up_h_pic "Traffic" "upload" "s(kb)" "t(h:m:s)" upload_h_history;
+                G.do_draw_up_h_pic "Traffic" "upload" "s(kb)" "t(h:m:s)" upload_h_history;
                 http_send_bin r buf "bw_h_upload.png"
             | true -> raise Not_found)
 
         | "bw_h_upload.jpg" ->
             (match http_error_no_gd "jpg" with
             | false ->
-                do_draw_up_h_pic "Traffic" "upload" "s(kb)" "t(h:m:s)" upload_h_history;
+                G.do_draw_up_h_pic "Traffic" "upload" "s(kb)" "t(h:m:s)" upload_h_history;
                 http_send_bin r buf "bw_h_upload.jpg"
             | true -> raise Not_found)
 
         | "tag.png" ->
             (match http_error_no_gd "png" with
             | false ->
-                do_draw_tag !!html_mods_vd_gfx_tag_title download_history upload_history;
+                G.do_draw_tag !!html_mods_vd_gfx_tag_title download_history upload_history;
                 http_send_bin r buf "tag.png"
             | true -> raise Not_found)
 
         | "tag.jpg" ->
             (match http_error_no_gd "jpg" with
             | false ->
-                do_draw_tag !!html_mods_vd_gfx_tag_title download_history upload_history;
+                G.do_draw_tag !!html_mods_vd_gfx_tag_title download_history upload_history;
                 http_send_bin r buf "tag.jpg"
             | true -> raise Not_found)
 
@@ -1430,8 +1433,13 @@ let http_handler o t r =
 
               | [ "setoption", _ ; "option", name; "value", value ] ->
                   html_open_page buf t r true;
-                  CommonInteractive.set_fully_qualified_options name value;
-                  Buffer.add_string buf "Option value changed"
+		  if (o.conn_user == default_user) || !!enable_user_config then
+		    begin
+                      CommonInteractive.set_fully_qualified_options name value;
+                      Buffer.add_string buf "Option value changed"
+		    end
+		  else
+                    Buffer.add_string buf "Only 'admin' is allowed to change options"
 
               | args ->
                   List.iter (fun (s,v) ->
