@@ -37,7 +37,56 @@ open CommonOptions
 open CommonTypes
 open Int64ops
 
+(* prints a new logline with date, module and starts newline *)
+let lprintf_nl () =
+  lprintf "%s"
+    (log_time ()); lprintf_nl2
 
+(* prints a new logline with date, module and does not start newline *)
+let lprintf_n () =
+  lprintf "%s"
+    (log_time ()); lprintf
+
+let verify_user_admin () =
+  let warning =
+    "SECURITY WARNING: user admin has an empty password, use command: add_user admin password\n"
+  in
+  let found = ref false in
+  let empty_password = ref false in
+  List.iter (fun (user,pass) ->
+    if user = "admin" then begin
+      found := true;
+      if pass = Md4.string "" then
+        empty_password := true
+    end
+  ) !!users;
+  if not !found then begin
+    lprintf_nl () "SECURITY INFO: user 'admin' has to be present, creating...";
+    users =:= ("admin", Md4.string "") :: !!users;
+    empty_password := true
+  end;
+  if !empty_password && not !!enable_user_config then
+    begin
+      lprintf_n () "%s" warning;
+      warning
+    end
+  else ""
+  
+let check_supported_os () =
+  let uname = Unix32.uname () in
+  let message = Printf.sprintf "MLDonkey is not able to run faultless under %s" uname; in
+  if uname <> "" && not (Unix32.os_supported ()) then begin
+    lprintf_nl () "%s" message;
+    message;
+  end
+  else ""
+
+let dns_works = ref false
+  
+let real_startup_message () =
+  !startup_message ^ (verify_user_admin ()) ^ (check_supported_os ()) 
+  ^ (if not !dns_works then "DNS resolution does not work" else "")
+      
 (* ripped from gui_downloads *)
 
 let calc_file_eta f =
@@ -905,6 +954,12 @@ let print_bw_stats buf =
   (size_of_int64 !nshared_bytes)
   (size_of_int64 !upload_counter)
 
+let console_topic () =
+  Printf.sprintf "(DL: %.1f | UL: %.1f) MLNet %s"
+    (( (float_of_int !udp_download_rate) +. (float_of_int !control_download_rate)) /. 1024.0)
+    (( (float_of_int !udp_upload_rate) +. (float_of_int !control_upload_rate)) /. 1024.0)
+    Autoconf.current_version
+
 let display_active_file_list buf o list =
   display_vd := true;
 
@@ -1617,5 +1672,203 @@ let print_gdstats buf o =
     )
   else
     (* fake call if no gd *)
-    CommonGraphics.do_draw_pic "" "" "" download_history download_history
+    DriverGraphics.G.do_draw_pic "" "" "" download_history download_history
 
+let buildinfo html buf =
+  let s =
+  (
+        "Version:\t MLNet Multi-Network p2p client version " ^ Autoconf.current_version
+      ^ (if Autoconf.scm_version <> "" then "\nSCM version:\t " ^ Autoconf.scm_version else "")
+      ^ "\nNetworks:\t " ^ !networks_string
+      ^ "\nOcaml version:\t " ^ Sys.ocaml_version
+      ^ " - C compiler version: " ^ Autoconf.cc_version
+      ^ (if Autoconf.cxx_version <> "" then " - C++ compiler version: " ^ Autoconf.cxx_version else "")
+      ^ "\nBuild on:\t " ^ Autoconf.build_system ^ " (" ^ Unix2.endianness () ^ ")"
+      ^ (if Autoconf.glibc_version = "" then "" 
+          else
+            let real_glibc_version = MlUnix.glibc_version_num () in
+            if real_glibc_version = "" || real_glibc_version = Autoconf.glibc_version 
+              then " with glibc " ^ Autoconf.glibc_version
+            else 
+              Printf.sprintf " (Warning: glibc version mismatch, %s present on your system, MlDonkey was compiled with %s)"
+              real_glibc_version Autoconf.glibc_version)  
+      ^ (if Autoconf.configure_arguments <> "" then
+           "\nConfigure args:\t " ^ Autoconf.configure_arguments else "")
+      ^ (if !patches_string <> "" then "\nPatches:/t " ^ !patches_string else "")
+      ^ "\nFeatures:\t "
+          ^ (if BasicSocket.has_threads () then "threads" else "no-threads")
+          ^ (let s = Zlib.zlib_version_num () in Printf.sprintf " zlib%s" (if s <> "" then "-" ^ s else ""))
+          ^ (if Autoconf.bzip2 then
+	       begin
+	         let s =
+	           (* catch the exception in the case Bzip2.bzlib_version_num returns an empty string *)
+	           try
+	             List.hd(String2.split_simplify
+		   (Misc2.bzlib_version_num ()) ',') 
+		   with e -> ""
+		 in
+	         Printf.sprintf " bzip2%s" (if s <> "" then "-" ^ s else "")
+	       end
+	     else " no-bzip2")
+          ^ (if Autoconf.has_gd && Autoconf.has_gd_png && Autoconf.has_gd_jpg then
+	       Printf.sprintf " gd(jpg/png%s)"
+	         (let s = DriverGraphics.G.png_version_num () in
+		    if s <> "" then "-" ^ s else "")
+	     else "")
+          ^ (if Autoconf.has_gd && Autoconf.has_gd_png && not Autoconf.has_gd_jpg then
+	       Printf.sprintf " gd(png%s)"
+	         (let s = DriverGraphics.G.png_version_num () in
+		    if s <> "" then "-" ^ s else "")
+	     else "")
+	  ^ (if Autoconf.has_gd && not Autoconf.has_gd_png && Autoconf.has_gd_jpg then " gd(jpg)" else "")
+	  ^ (if not Autoconf.has_gd then " no-gd" else "")
+          ^ (if Autoconf.has_iconv then " iconv" else " no-iconv")
+          ^ (if Autoconf.check_bounds then " check-bounds" else " no-check-bounds")
+  )
+  in
+  if html then
+    begin
+      Printf.bprintf buf "\\<div class=\\\"cs\\\"\\>";
+      html_mods_table_header buf "versionTable" "results" [];
+      Printf.bprintf buf "\\<tr\\>";
+      html_mods_td buf [ ("", "srh", "Buildinfo"); ];
+      Printf.bprintf buf "\\</tr\\>\\<tr class=\\\"dl-1\\\"\\>";
+      html_mods_td buf [ ("", "sr", Str.global_replace (Str.regexp "\n") "\\<br\\>" s); ];
+      Printf.bprintf buf "\\</tr\\>\\</table\\>\\</div\\>\\</div\\>";
+    end
+  else
+    Printf.bprintf buf "\n\t--Buildinfo--\n%s\n" s
+
+let runinfo html buf o =
+  let dis_mess = "disabled, to enable adjust web_infos in downloads.ini for automatic download" in
+  let ui_user = o.conn_user.ui_user_name in
+  let s =
+  (
+        "User:\t\t " ^ ui_user
+      ^   (if List.assoc ui_user !!users = Md4.string "" then " (Warning: empty Password)"
+           else " (PW Protected)")
+      ^	  " - uptime: " ^ Date.time_to_string (last_time () - start_time) "verbose"
+      ^ "\nEnabled nets:\t"
+      ^   (if Autoconf.donkey = "yes" && !!enable_donkey then " Donkey" else "")
+      ^   (if Autoconf.donkey = "yes" && !!enable_overnet then " Overnet" else "")
+      ^   (if Autoconf.donkey = "yes" && !!enable_kademlia then " Kademlia" else "")             
+      ^   (if Autoconf.bittorrent = "yes" && !!enable_bittorrent then " BitTorrent" else "")
+      ^   (if Autoconf.fasttrack = "yes" && !!enable_fasttrack then " Fasttrack" else "")
+      ^   (if Autoconf.gnutella = "yes" && !!enable_gnutella then " Gnutella" else "")
+      ^   (if Autoconf.gnutella2 = "yes" && !!enable_gnutella2 then " G2" else "")
+      ^   (if Autoconf.filetp = "yes" && !!enable_fileTP then " FileTP" else "")
+      ^ "\nServer usage:\t " ^ (if !!enable_servers then "enabled" else "disabled (you are not able to connect to ED2K Servers)")
+      ^ "\nGeoip:\t\t " ^ (if !Geoip.active then "enabled, GeoLite data created by MaxMind, available from http://maxmind.com/"
+          else dis_mess)
+      ^ "\nIP blocking:\t " ^ (let r1,r2 = Ip_set.block_stats () in
+          if r1 = 0 then dis_mess else Printf.sprintf "enabled, %d ranges loaded - optimized to %d" r1 r2)
+      ^ (if not !dns_works then
+	    Printf.sprintf "\nDNS:\t\t DNS resolution not available, web_infos %s not work"
+	      (if Autoconf.bittorrent = "yes" then "and BT does" else "do")
+	 else "")
+      ^ "\nSystem info:\t " ^ (let uname = Unix32.uname () in
+          if uname <> "" then uname ^
+	    (if not (Unix32.os_supported ()) then " - \nWARNING:\t not supported operating system" else "")
+          else "unknown")
+      ^ "\n\t\t language: " ^ Charset.default_language
+      ^ " - locale: " ^ Charset.locstr
+      ^ " - UTC offset: " ^ Rss_date.mk_timezone (Unix.time ())
+      ^ "\n\t\t max_string_length: " ^ string_of_int Sys.max_string_length
+      ^ " - word_size: " ^ string_of_int Sys.word_size
+      ^ " - max_array_length: " ^ string_of_int Sys.max_array_length
+      ^ "\n\t\t max file descriptors: " ^ string_of_int (Unix2.c_getdtablesize ())
+      ^ " - max useable file size: " ^ 
+	    (match Unix2.c_sizeofoff_t () with
+	     | 4 -> "2GB"
+	     |  _ -> Printf.sprintf "2^%d-1 bits (do the maths ;-p)" ((Unix2.c_sizeofoff_t () *8)-1)
+	     )
+  )    
+  in
+  if html then
+    begin
+      Printf.bprintf buf "\\<div class=\\\"cs\\\"\\>";
+      html_mods_table_header buf "versionTable" "results" [];
+      Printf.bprintf buf "\\<tr\\>";
+      html_mods_td buf [ ("", "srh", "Runinfo"); ];
+      Printf.bprintf buf "\\</tr\\>\\<tr class=\\\"dl-1\\\"\\>";
+      html_mods_td buf [ ("", "sr", Str.global_replace (Str.regexp "\n") "\\<br\\>" s); ];
+      Printf.bprintf buf "\\</tr\\>\\</table\\>\\</div\\>\\</div\\>";
+    end
+  else
+    Printf.bprintf buf "\n\t--Runinfo--\n%s\n" s
+
+let diskinfo html buf =
+  let list = ref [] in
+  ignore (search_incoming_files ());
+  ignore (search_incoming_directories ());
+  List.iter (fun dir ->
+     list := (dir.shdir_dirname, (Printf.sprintf "shared (%s)" dir.shdir_strategy))
+     :: !list) !!shared_directories;
+  list := (!!temp_directory, "temp/downloading") :: !list;
+  list := (Sys.getcwd (), "core/ini files") :: !list;
+
+  let len_dir = ref 9 in
+  let len_strategy = ref 29 in (* "shared (incoming_directories)" *)
+  List.iter ( fun (dir, strategy) ->
+    len_dir := maxi !len_dir (String.length dir);
+    len_strategy := maxi !len_strategy (String.length strategy)
+  ) !list;
+  let fill_dir = String.make (!len_dir - 9) ' ' in
+  let fill_dir_line = String.make (!len_dir - 9) '-' in
+  let fill_strategy = String.make (!len_strategy - 4) ' ' in
+  let fill_strategy_line = String.make (!len_strategy - 4) '-' in
+  let counter = ref 0 in
+  if html then
+      html_mods_table_header buf "sharesTable" "shares" [
+       ( "0", "srh", "Directory", "Directory" ) ;
+       ( "0", "srh", "Directory type", "Type" ) ;
+       ( "1", "srh ar", "HDD used", "used" ) ;
+       ( "1", "srh ar", "HDD free", "free" ) ;
+       ( "1", "srh ar", "% free", "% free" ) ;
+       ( "0", "srh", "Filesystem", "FS" ) ]
+  else
+    begin
+      Printf.bprintf buf "\n\t--Diskinfo--\n";
+      Printf.bprintf buf "Directory%s|Type%s|    used|    free|%%free|Filesystem\n"
+        fill_dir fill_strategy;
+      Printf.bprintf buf "---------%s+----%s+--------+--------+-----+----------\n"
+        fill_dir_line fill_strategy_line;
+    end;
+  List.iter (fun (dir, strategy) ->
+	incr counter;
+	let diskused =
+    	  match Unix32.diskused dir with
+	  | None -> Printf.sprintf "---"
+	  | Some du -> size_of_int64 du
+	in
+	let diskfree =
+    	  match Unix32.diskfree dir with
+	  | None -> Printf.sprintf "---"
+	  | Some df -> size_of_int64 df
+	in
+	let percentfree =
+    	  match Unix32.percentfree dir with
+	  | None -> Printf.sprintf "---"
+	  | Some p -> Printf.sprintf "%d%%" p
+	in
+	let filesystem = Unix32.filesystem dir in
+	if html then
+	  begin
+	    Printf.bprintf buf "\\<tr class=\\\"%s\\\"\\>
+	\\<td class=\\\"sr\\\"\\>%s\\</td\\>
+	\\<td class=\\\"sr\\\"\\>%s\\</td\\>
+	\\<td class=\\\"sr ar\\\"\\>%s\\</td\\>
+	\\<td class=\\\"sr ar\\\"\\>%s\\</td\\>
+	\\<td class=\\\"sr ar\\\"\\>%s\\</td\\>
+	\\<td class=\\\"sr\\\"\\>%s\\</td\\>\\</tr\\>"
+	    (if !counter mod 2 == 0 then "dl-1" else "dl-2")
+	    dir strategy diskused diskfree percentfree filesystem
+	  end
+	else
+	  Printf.bprintf buf "%-*s|%-*s|%8s|%8s|%5s|%-s\n"
+	    (maxi !len_dir (!len_dir - String.length dir)) dir
+	    (maxi !len_strategy (!len_strategy - String.length strategy)) strategy
+	    diskused diskfree percentfree filesystem
+    	) !list;
+  if html then
+    Printf.bprintf buf "\\</table\\>\\</td\\>\\<tr\\>\\</table\\>\\</div\\>"
