@@ -386,7 +386,8 @@ let gui_initialize gui =
   gui.gui_initialized <- true;
   networks_iter_all (fun n ->
       gui_send gui (Network_info (network_info n)));
-  gui_send gui (Console (DriverControlers.text_of_html !!motd_html));
+  gui_send gui (Console ((DriverControlers.text_of_html !!motd_html) ^ "\n"));
+  gui_send gui (Console (DriverInteractive.real_startup_message ()));
   
   
   if gui.gui_poll then begin
@@ -615,7 +616,18 @@ let gui_reader (gui: gui_record) t _ =
               ) list
           
           | P.SetOption (name, value) ->
-              CommonInteractive.set_fully_qualified_options name value
+	      if (gui.gui_conn.conn_user == default_user) || !!enable_user_config then
+		CommonInteractive.set_fully_qualified_options name value
+	      else
+	        begin
+                  let o = gui.gui_conn in
+                  let buf = o.conn_buf in
+                  Buffer.reset buf; 
+                  Buffer.add_string buf "\nOnly 'admin' is allowed to change options\n";
+                  gui_send gui (P.Console (
+                      DriverControlers.dollar_escape o false
+                        (Buffer.contents buf)))
+		end
           
           | P.CloseSearch (num, forget) ->
               let s = List.assoc num gui.gui_searches in
@@ -661,7 +673,18 @@ let gui_reader (gui: gui_record) t _ =
                     network_extend_search r s e)
           
           | P.KillServer -> 
-              CommonInteractive.clean_exit 0
+	      if gui.gui_conn.conn_user == default_user then
+		CommonInteractive.clean_exit 0
+	      else
+	        begin
+                  let o = gui.gui_conn in
+                  let buf = o.conn_buf in
+                  Buffer.reset buf; 
+                  Buffer.add_string buf "\nOnly 'admin' is allowed to kill MLDonkey\n";
+                  gui_send gui (P.Console (
+                      DriverControlers.dollar_escape o false
+                        (Buffer.contents buf)))
+		end
           
           | P.Search_query s ->
               
