@@ -89,7 +89,6 @@ let hourly_timer timer =
      && !CommonWeb.hours mod !!backup_options_delay = 0 then
        CommonComplexOptions.backup_options ();
   DriverControlers.check_calendar ();
-  CommonWeb.connect_redirector ();
   CommonFile.propose_filenames ()
 
 
@@ -275,6 +274,7 @@ let load_config () =
   (try
       Options.load downloads_ini;
       Options.load users_ini;
+      ignore (DriverInteractive.verify_user_admin ())
     with e ->
         lprintf_nl () "Exception %s during options load" (Printexc2.to_string e);
         exit 70);
@@ -381,6 +381,8 @@ let load_config () =
   ) !!CommonComplexOptions.shared_directories;
   Unix2.safe_mkdir "searches";
   Unix2.can_write_to_directory "searches";
+  Unix2.safe_mkdir "web_infos";
+  Unix2.can_write_to_directory "web_infos";
   Unix2.safe_mkdir !!temp_directory;
   Unix2.can_write_to_directory !!temp_directory
 
@@ -397,9 +399,9 @@ let _ =
   (
     let hostname = "www.mldonkey.net" in
     try
-      ignore(Ip.from_name hostname)
-    with
-     e ->
+      ignore(Ip.from_name hostname);
+      DriverInteractive.dns_works := true
+    with e ->
         lprintf (_b "\nDNS resolution does not work! Looking up %s failed with %s.")
            hostname (Printexc2.to_string e);
 	lprintf "
@@ -407,7 +409,7 @@ The core therefore is unable to get eDonkey serverlists and loading
 .torrent files via dllink from websites is also impossible.
 If you are using MLDonkey in a chroot environment you should
 consider reading this article to get DNS support back:
-http://mldonkey.berlios.de/modules.php?name=Wiki&pagename=Chroot\n\n");
+http://mldonkey.sourceforge.net/Chroot\n\n");
   (
     let real_glibc_version = MlUnix.glibc_version_num () in
       if real_glibc_version <> Autoconf.glibc_version
@@ -473,6 +475,10 @@ or getting a binary compiled with glibc %s.\n\n")
   add_infinite_timer 3600. hourly_timer;
   add_infinite_timer 0.1 CommonUploads.upload_download_timer;
 
+  if Autoconf.system = "mingw" then
+    add_infinite_timer 1. (fun timer ->
+        MlUnix.set_console_title (DriverInteractive.console_topic ()));
+
   List.iter
     CommonShared.shared_add_directory
   !!CommonComplexOptions.shared_directories;
@@ -563,6 +569,19 @@ or getting a binary compiled with glibc %s.\n\n")
     (Sys.Signal_handle (fun _ -> lprintf_nl () "Received SIGTERM, stopping MLDonkey...";
         CommonInteractive.clean_exit 0));
 
+  if not Autoconf.windows then
+  MlUnix.set_signal  Sys.sigusr1
+    (Sys.Signal_handle (fun _ -> lprintf_nl () "Received SIGUSR1, saving options...";
+        DriverInteractive.save_config ()));
+
+  if not Autoconf.windows then
+  MlUnix.set_signal  Sys.sigusr2
+    (Sys.Signal_handle (fun _ ->
+	lprintf_n () "Received SIGUSR2, starting garbage collection...";
+	Gc.compact ();
+	lprintf " finished";
+	lprint_newline ()));
+
   if !verbose then lprintf_nl () (_b "Activated system signal handling")
 
 let _ =
@@ -591,7 +610,7 @@ for config files at the end. *)
         lprintf_nl () (_b "Exiting...");
         exit 73;
   end;
-  Unix32.external_start (CommonGlobals.version());
+  Unix32.external_start ();
 
   (
     let pid_filename =
@@ -631,7 +650,7 @@ for config files at the end. *)
            lprintf_nl () "Exception %s in do_at_exit while closing sockets."
              (Printexc2.to_string e);
       );
-      CommonGraphics.remove_files ();
+      DriverGraphics.G.remove_files ();
       (* In case we have no more space on filesystem for
          config files, remove the security space file *)
       Sys.remove security_space_filename;
