@@ -376,6 +376,7 @@ let decode_az_style s =
       | "lt" -> Brand_libtorrent
       | "MP" -> Brand_moopolice
       | "UT" -> Brand_utorrent
+      | "KT" -> Brand_ktorrent
       | _ -> Brand_unknown
     in
     if brand = Brand_unknown then None else
@@ -630,7 +631,7 @@ let parse_software s =
   let default = (Brand_unknown, "") in
   let rec iter l =
     match l with
-      [] -> lprintf_nl () "Unknown BT client software version, report the next line to http://mldonkey.berlios.de/modules.php?name=Wiki&pagename=UnknownBtClients%s\nBTUC:\"%s\"" Autoconf.current_version (String.escaped s);
+      [] -> lprintf_nl () "Unknown BT client software version, report the next line to http://mldonkey.sourceforge.net/UnknownBtClients%s\nBTUC:\"%s\"" Autoconf.current_version (String.escaped s);
             default
       | d :: t -> match (d s) with 
                   | None -> iter t
