@@ -61,13 +61,22 @@ let lprintf_n () =
     (log_time ()); lprintf
 
 let op_file_all_sources file =
-(*      lprintf "file_sources\n"; *)
   let list = ref [] in
   Hashtbl.iter (fun _ c ->
       list := (as_client c) :: !list
   ) file.file_clients;
   !list
 
+let op_file_active_sources file =
+  let list = ref [] in
+  Hashtbl.iter (fun _ c ->
+      let as_c = as_client c in
+      match client_state as_c with
+        Connected_downloading _ -> list := as_c :: !list
+      | _ -> ()
+  ) file.file_clients;
+  !list
+
 let op_file_files file impl =
   match file.file_swarmer with
     None -> [CommonFile.as_file impl]
@@ -145,7 +154,7 @@ let op_file_print_html file buf =
          tracker_string := (if tracker.tracker_enabled then "" else "*") ^ 
 	   !tracker_string ^ (shorten tracker.tracker_url !!max_name_len) ^ " "
       ) file.file_trackers;
-      Printf.sprintf "%s" !tracker_string)) ];
+      !tracker_string)) ];
 
   Printf.bprintf buf "\\</tr\\>\\<tr class=\\\"dl-%d\\\"\\>" (html_mods_cntr ());
 
@@ -242,13 +251,13 @@ let op_file_print_html file buf =
               Printf.bprintf buf "\\</tr\\>\\<tr class=\\\"dl-%d\\\"\\>" (html_mods_cntr ());
               html_mods_td buf [
 		("Tracker id", "sr br", "Tracker id");
-		("", "sr", Printf.sprintf "%s" t.tracker_id) ]
+		("", "sr", t.tracker_id) ]
             end;
 	    if String.length t.tracker_key > 0 then begin
               Printf.bprintf buf "\\</tr\\>\\<tr class=\\\"dl-%d\\\"\\>" (html_mods_cntr ());
               html_mods_td buf [
 		("Tracker key", "sr br", "Tracker key");
-		("", "sr", Printf.sprintf "%s" t.tracker_key) ]
+		("", "sr", t.tracker_key) ]
 	    end 
 	  end in
   print_first_tracker file.file_trackers;
@@ -408,6 +417,8 @@ let op_file_info file =
     P.file_chunks_age = last_seen;
     P.file_uids = [Uid.create (BTUrl file.file_id)];
     P.file_sub_files = file.file_files;
+    P.file_active_sources = List.length (op_file_active_sources file);
+    P.file_all_sources = (Hashtbl.length file.file_clients);
   }
 
 let op_ft_info ft =
@@ -610,6 +621,7 @@ let load_torrent_from_web r ft =
       if ft_state ft = FileDownloading then begin
           load_torrent_file filename;
           file_cancel (as_ft ft);
+	  (try Sys.remove filename with _ -> ())
         end)
 
 let valid_torrent_extension url =
@@ -825,7 +837,7 @@ let commands =
           else
             Printf.bprintf buf "Not enough parameters\n";
       ""
-    ), _s " <filename> <comment>:\t\tgenerate the corresponding <filename> .torrent file with <comment> in torrents/tracked/.\n\t\t\t\t\tThe file is automatically tracked, and seeded if in incoming/";
+    ), _s "<filename> <comment> :\tgenerate the corresponding <filename> .torrent file with <comment> in torrents/tracked/.\n\t\t\t\t\tThe file is automatically tracked, and seeded if in incoming/";
 
     "torrents", "Network/Bittorrent", Arg_none (fun o ->
       let buf = o.conn_buf in
@@ -859,7 +871,7 @@ let commands =
           else
             Printf.bprintf buf "Tracker not activated (tracker_port = 0)\n";
         _s ""
-    ), _s " :\t\t\t\tprint all .torrent files on this server";
+    ), _s ":\t\t\t\tprint all .torrent files on this server";
 
     "seeded_torrents", "Network/Bittorrent", Arg_none (fun o ->
       List.iter (fun file ->
@@ -868,12 +880,12 @@ let commands =
       ) !current_files;
       _s "done"
 
-    ), _s " :\t\t\tprint all seeded .torrent files on this server";
+    ), _s ":\t\t\tprint all seeded .torrent files on this server";
 
     "reshare_torrents", "Network/Bittorrent", Arg_none (fun o ->
       share_files ();
       _s "done"
-    ), _s " :\t\t\trecheck torrents/* directories for changes";
+    ), _s ":\t\t\trecheck torrents/* directories for changes";
 
     "rm_old_torrents", "Network/Bittorrent", Arg_none (fun o ->
       let files_outdated = Unix2.list_directory old_directory in
@@ -897,7 +909,7 @@ let commands =
             Sys.remove (Filename.concat old_directory file)
       ) files_outdated;
       _s ""
-    ), _s " :\t\t\t\tremove all old .torrent files";
+    ), _s ":\t\t\tremove all old .torrent files";
 
     "stop_all_bt", "Network/Bittorrent", Arg_none (fun o ->
       List.iter (fun file -> BTClients.file_stop file ) !current_files;
@@ -908,7 +920,7 @@ let commands =
       else
         Printf.bprintf buf "started sending stops...\n";
        _s ""
-    ), _s " :\t\t\t\tstops all bittorrent downloads, use this if you want to make sure that the stop signal actualy gets to the tracker\n\t\t\t\twhen shuting mlnet down, but you have to wait till the stops get to the tracker and not wait too long,\n\t\t\t\tso mldonkey reconnects to the tracker :)";
+    ), _s ":\t\t\t\tstops all bittorrent downloads, use this if you want to make sure that the stop signal actualy gets to the tracker\n\t\t\t\t\twhen shuting mlnet down, but you have to wait till the stops get to the tracker and not wait too long,\n\t\t\t\t\tso mldonkey reconnects to the tracker :)";
 
     "tracker", "Network/Bittorrent", Arg_multiple (fun args o ->
         try
@@ -954,13 +966,13 @@ let commands =
             else
               Printf.bprintf buf "Not enough or wrong parameters.";
             _s ""        
-    ), " <num> <url> <url>... :\t\t\tadd urls as trackers for num.";
+    ), "<num> <url> <url>... :\t\tadd URLs as trackers for num";
 
 (* TODO : add some code from make_torrent
     "print_torrent", Arg_one (fun filename o ->
 
         ".torrent file printed"
-    ), " <filename.torrent> : print the content of filename"
+    ), "<filename.torrent> :\t\tprint the content of filename"
  *)
 
   ]
@@ -991,7 +1003,7 @@ let _ =
 
   file_ops.op_file_all_sources <- op_file_all_sources;
   file_ops.op_file_files <- op_file_files;
-  file_ops.op_file_active_sources <- op_file_all_sources;
+  file_ops.op_file_active_sources <- op_file_active_sources;
   file_ops.op_file_debug <- op_file_debug;
   file_ops.op_file_commit <- op_file_commit;
   file_ops.op_file_print_html <- op_file_print_html;
