@@ -159,11 +159,11 @@ let _ =
             addr, port
           in
           let s = new_server addr port in
-          true
+          "", true
       | "dc://" :: "friend" :: nick :: [] ->  
           let c = new_client nick in
           friend_add (as_client c.client_client);
-          true
+          "", true
       | "dc://" :: "friend" :: nick :: addr :: _ ->  
           let addr, port = 
             let ip, port = match String2.split addr ':' with
@@ -176,8 +176,8 @@ let _ =
           let c = new_client nick in
           c.client_addr <- Some (addr, port);
           friend_add (as_client c.client_client);
-          true
-      | _ -> false
+          "", true
+      | _ -> "", false
   )
 
 let _ =
@@ -315,6 +315,7 @@ let _ =
         P.file_last_seen = BasicSocket.last_time ();
         P.file_priority = file_priority (as_file file.file_file);
         P.file_uids = [];
+        P.file_sub_files = [];
       }    
   );
   (*
@@ -388,6 +389,7 @@ let _ =
 let _ =
   network.op_network_save_complex_options <- (fun _ -> ());
   network.op_network_save_sources <- (fun _ -> ());
+  network.op_network_update_options <- (fun _ -> ());
   network.op_network_add_server <- (fun ip port ->
       as_server (new_server ip port).server_server
   )
