@@ -84,7 +84,7 @@ let add_source file ip port serverIP serverPort =
                         (* without server, we can't request a callback *)
                         let s = Hashtbl.find servers_by_key serverIP in
                         if serverPort = s.server_port then
-                            Indirect_address ( serverIP, serverPort, id_of_ip ip, port )
+                            Indirect_address ( serverIP, serverPort, id_of_ip ip, port, ip )
                         else
                             raise Not_found
                     with _ ->
@@ -647,7 +647,7 @@ let parse_compatible_client num old_brand =
     | 6 -> Brand_hydranode
     | 10 -> Brand_mldonkey3
     | 20 -> Brand_lphant
-    | _ -> lprintf_nl () "unknown compatibleclient %d (please report to dev team)" num; Brand_unknown
+    | _ -> Brand_unknown
 
 let parse_mod_version s c =
   let rec iter i len =
@@ -700,7 +700,7 @@ let update_emule_proto_from_tags c tags =
           for_int_tag tag (fun i ->
             c.client_brand <- parse_compatible_client i c.client_brand;
             if c.client_brand = Brand_unknown then
-              lprintf_nl () "[compatibleclient] Brand_unknown %s" (full_client_identifier c);
+              lprintf_nl () "unknown compatibleclient %d (%s) (please report to dev team)" i (full_client_identifier c)
           )
       | Field_UNKNOWN "compression" ->
           for_int_tag tag (fun i ->
@@ -819,7 +819,6 @@ let is_valid_client md4 =
   - do *not* ask for sources, we can't be sure, the client is still downloading the file!
 *)
 let client_has_file c file =
-  DonkeyNeighbours.new_neighbour c file;
   DonkeySources.set_request_result c.client_source file.file_sources File_found
 
 (*
@@ -1001,7 +1000,7 @@ let send_signature c =
     end;
 
     let pubkey = get_pubkey c in
-    let signature = Unix32.create_signature pubkey (String.length pubkey) c.client_req_challenge !ip_type !ip in
+    let signature = DonkeySui.SUI.create_signature pubkey (String.length pubkey) c.client_req_challenge !ip_type !ip in
     
     if !verbose_msg_clients then begin
       lprintf_nl () "%s [send_signature] [sigLen: %d] [keyLen: %d] [reqChall: %Ld] [ipType: %d] [ip: %Ld]" (full_client_identifier c) (String.length signature) (String.length pubkey) c.client_req_challenge !ip_type !ip;
@@ -1634,6 +1633,38 @@ is checked for the file.
           lprintf_nl () "Sending %d Files in ViewFilesReqReply" (List.length !published_files);
       client_send_files sock !published_files
   
+  (*TODO: real directory support*)
+  | M.ViewDirsReq t when !CommonUploads.has_upload = 0 && 
+    (match !!allow_browse_share with
+        1 -> client_friend_tag land client_type c <> 0
+      | 2 -> true
+      | _ -> false) -> 
+      let published_dirs = ["FIXME"] in
+      if !verbose_msg_clients then
+          lprintf_nl () "Sending %d Dirs in ViewDirsReplyReq" (List.length published_dirs);
+      client_send c (M.ViewDirsReplyReq published_dirs)
+  
+  (*TODO: real directory support*)
+  (*TODO: "!Incomplete Files" support*)
+  | M.ViewFilesDirReq t when !CommonUploads.has_upload = 0 && 
+    (match !!allow_browse_share with
+        1 -> client_friend_tag land client_type c <> 0
+      | 2 -> true
+      | _ -> false) -> 
+      let files = DonkeyShare.all_shared () in
+      let published_files = ref [] in
+      List.iter (fun f ->
+          let filename = file_best_name f in
+          if not (String2.starts_with filename "hidden.") then
+            published_files := f :: !published_files
+      ) files;
+(*
+       lprintf "ASK VIEW FILES\n"; 
+       *)
+      if !verbose_msg_clients then
+          lprintf_nl () "Sending %d Files in ViewFilesReqReply" (List.length !published_files);
+      client_send_dir sock t !published_files
+
   | M.QueryFileReq t ->
       let md4 = t.M.QueryFile.md4 in
       c.client_requests_received <- c.client_requests_received + 1;
@@ -1736,7 +1767,7 @@ is checked for the file.
         lprintf_nl () "%s [ESigReq] [verify_signature] [keyLen: %d] [sigLen: %d] [sentChall: %Ld] [ipType %d] [ip: %Ld]" (full_client_identifier c) (String.length pubKey) (String.length t.Q.signature) c.client_sent_challenge !ip_type !id;
       end;
 
-      let verified = Unix32.verify_signature pubKey (String.length pubKey) t.Q.signature (String.length t.Q.signature) c.client_sent_challenge !ip_type !id in
+      let verified = DonkeySui.SUI.verify_signature pubKey (String.length pubKey) t.Q.signature (String.length t.Q.signature) c.client_sent_challenge !ip_type !id in
       c.client_sui_verified <- Some verified;
       c.client_sent_challenge <- Int64.zero;
       client_must_update c;
@@ -2141,7 +2172,7 @@ let read_first_message overnet m sock =
                 Invalid_address (!name, Md4.to_string t.CR.md4)
             | Some (ip,port) ->
                 if Ip.usable ip then
-                    Indirect_address (ip, port, id_of_ip t.CR.ip, t.CR.port)
+                    Indirect_address (ip, port, id_of_ip t.CR.ip, t.CR.port, (peer_ip sock))
                 else
                     Invalid_address (!name, Md4.to_string t.CR.md4)
         else
@@ -2545,7 +2576,7 @@ let _ =
             let c = new_client s_uid in        
             reconnect_client c
         | Invalid_address _ -> ()
-        | Indirect_address (server_ip, server_port, id, port) ->
+        | Indirect_address (server_ip, server_port, id, port, real_ip) ->
 
        if low_id server_ip && Ip.reachable server_ip then
               query_id server_ip server_port id; 
@@ -2578,27 +2609,30 @@ a FIFO from where they are removed after 30 minutes. What about using
   DonkeySources.functions.DonkeySources.function_add_location <- (fun
       s_uid file_uid ->
       try
-        let c = new_client s_uid in
         let file = find_file (Md4.of_string file_uid) in
+        let c = new_client s_uid in
         
         CommonFile.file_add_source (CommonFile.as_file file.file_file) 
         (CommonClient.as_client c.client_client);
       
-      with e -> 
-        if !verbose then begin
-          lprintf_nl () "add_location: exception %s" (Printexc2.to_string e);
-        end
+      with
+	Not_found -> ()
+      | e -> 
+        if !verbose then
+          lprintf_nl () "add_location: exception %s" (Printexc2.to_string e)
   );
   
   DonkeySources.functions.DonkeySources.function_remove_location <- (fun
       s_uid file_uid ->
       try
-        let c = new_client s_uid in
         let file = find_file (Md4.of_string file_uid) in
+        let c = new_client s_uid in
         CommonFile.file_remove_source (CommonFile.as_file file.file_file)
         (CommonClient.as_client c.client_client);
         
-      with e -> 
+      with
+	Not_found -> ()
+      | e -> 
         if !verbose then
           lprintf_nl () "remove_location for file_md4 %s: exception %s"
       file_uid (Printexc2.to_string e)
