@@ -17,6 +17,7 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *)
 
+open Int64ops
 open Printf2
 open Md4
 
@@ -45,9 +46,17 @@ open DonkeyClient
 open CommonGlobals
 open DonkeyStats
 
-let verbose_upload = false
-      
-let msg_block_size_int = 10000
+(* prints a new logline with date, module and starts newline *)
+let lprintf_nl () =
+  lprintf "%s[EDK] "
+    (log_time ()); lprintf_nl2
+
+(* prints a new logline with date, module and does not start newline *)
+let lprintf_n () =
+  lprintf "%s[EDK] "
+    (log_time ()); lprintf
+
+let msg_block_size_int = 10240
 let msg_block_size = Int64.of_int msg_block_size_int
 let upload_buffer = String.create msg_block_size_int
 let max_msg_size = 15000
@@ -78,13 +87,11 @@ module NewUpload = struct
     let rec send_small_block c sock file begin_pos len_int = 
 (*      lprintf "send_small_block %d\n" len_int; *)
 (*      let len_int = Int32.to_int len in *)
-      CommonUploads.consume_bandwidth len_int;
       try
-        if !verbose then begin
-            lprintf "send_small_block(%s-%s) %Ld %d\n"
-              c.client_name (brand_to_string c.client_brand)
+	if !verbose_upload then
+	  lprintf_nl () "send_small_block (%s) %Ld %d"
+	    (full_client_identifier c)
             (begin_pos) (len_int);
-          end;
         
         let msg =  
           (
@@ -93,7 +100,7 @@ module NewUpload = struct
             M.BlocReq {  
               B.md4 = file.file_md4;
               B.start_pos = begin_pos;
-              B.end_pos = Int64.add begin_pos (Int64.of_int len_int);
+              B.end_pos = begin_pos ++ (Int64.of_int len_int);
               B.bloc_str = "";
               B.bloc_begin = 0;
               B.bloc_len = 0; 
@@ -106,49 +113,46 @@ module NewUpload = struct
         DonkeyProtoCom.new_string msg upload_buffer;
         Unix32.read (file_fd file) begin_pos upload_buffer slen len_int;
         let uploaded = Int64.of_int len_int in
-        count_upload c file uploaded;
-        network_must_update network;
+        count_upload c uploaded;
+	CommonUploads.consume_bandwidth len_int;
         (match file.file_shared with None -> ()
           | Some impl ->
               shared_must_update_downloaded (as_shared impl);
               impl.impl_shared_uploaded <- 
-                Int64.add impl.impl_shared_uploaded uploaded);
-        if c.client_connected then
-          printf_string "U[OUT]"
-        else
-          printf_string "U[IN]";
+                impl.impl_shared_uploaded ++ uploaded);
         
         write_string sock upload_buffer;
         check_end_upload c sock
-      with e -> 
-          if !verbose_hidden_errors then lprintf "Exception %s in send_small_block\n" (Printexc2.to_string e)
+      with
+	End_of_file -> lprintf_nl () "Can not send file %s to %s, file removed?"
+			 (file_best_name file) (full_client_identifier c)
+      | e -> if !verbose then lprintf_nl ()
+	       "Exception %s in send_small_block" (Printexc2.to_string e)
     
     let rec send_client_block c sock per_client =
 (*      lprintf "send_client_block\n"; *)
-      if per_client > 0 && CommonUploads.remaining_bandwidth () > 0 then
+      if per_client > 0 && CommonUploads.can_write_len sock max_msg_size then
         match c.client_upload with
         | Some ({ up_chunks = _ :: chunks } as up)  ->
             if up.up_file.file_shared = None then begin
 (* Is there a message to warn that a file is not shared anymore ? *)
                 c.client_upload <- None;
               end else
-            let max_len = Int64.sub up.up_end_chunk up.up_pos in
+            let max_len = up.up_end_chunk -- up.up_pos in
             let max_len = Int64.to_int max_len in
             let msg_block_size_int = mini msg_block_size_int per_client in
             if max_len <= msg_block_size_int then
 (* last block from chunk *)
               begin
-                if verbose_upload then begin
-                    lprintf "END OF CHUNK (%d) %Ld\n" max_len up.up_end_chunk; 
-                  end;
+                if !verbose_upload then
+                    lprintf_nl () "END OF CHUNK (%d) %Ld" max_len up.up_end_chunk; 
                 send_small_block c sock up.up_file up.up_pos max_len;
                 up.up_chunks <- chunks;
                 let per_client = per_client - max_len in
                 match chunks with
                   [] -> 
-                    if verbose_upload then begin
-                        lprintf "NO CHUNKS\n"; 
-                      end;
+                    if !verbose_upload then
+                        lprintf_nl () "NO CHUNKS";
                     c.client_upload <- None;
                 | (begin_pos, end_pos) :: _ ->
                     up.up_pos <- begin_pos;
@@ -160,11 +164,9 @@ module NewUpload = struct
               begin
                 send_small_block c sock up.up_file up.up_pos 
                   msg_block_size_int;
-                up.up_pos <- Int64.add up.up_pos 
-                  (Int64.of_int msg_block_size_int);
+                up.up_pos <- up.up_pos ++ (Int64.of_int msg_block_size_int);
                 let per_client = per_client-msg_block_size_int in
-                if can_write_len sock max_msg_size then
-                  send_client_block c sock per_client
+                send_client_block c sock per_client
               end
         | _ -> ()
     
@@ -173,14 +175,9 @@ module NewUpload = struct
       do_if_connected  c.client_source.DonkeySources.source_sock (fun sock ->
 (*    lprintf "upload_to_client %d connected\n"  (maxi max_msg_size size); *)
           
-(* changed in 2.5.27: mini instead of maxi *)
           let size = mini max_msg_size size in
-          if CommonUploads.can_write_len sock size then 
-            begin
-(*              lprintf "can_write_len %d\n"  (maxi max_msg_size size); *)
-              send_client_block c sock size;
-            end;
-          (match c.client_upload with
+          send_client_block c sock size;
+           (match c.client_upload with
               None -> ()
             | Some up ->
                 if !CommonUploads.has_upload = 0 then
