@@ -689,8 +689,8 @@ let string_of_client c =
   Printf.sprintf "client[%d] %s(%s) %s" (client_num c)
   c.client_name (brand_to_string c.client_brand)
   (match c.client_kind with
-      Indirect_address (server_ip, server_port, ip, port) ->
-        Printf.sprintf  " I[%s:%d]" (Ip.to_string (ip_of_id ip)) port;
+      Indirect_address (server_ip, server_port, ip, port, real_ip) ->
+        Printf.sprintf  " I[%s:%d]" (Ip.to_string real_ip) port;
     | Direct_address (ip,port) ->
         Printf.sprintf  " D[%s:%d]" (Ip.to_string ip) port;
     | Invalid_address _ -> ""
@@ -916,7 +916,7 @@ let _ =
 let client_id c =
   match c.client_kind with
     Direct_address (ip, port) -> (ip, port, zero)
-  | Indirect_address (server_ip, server_port, id, port) ->
+  | Indirect_address (server_ip, server_port, id, port, real_ip) ->
      (server_ip, server_port, id)
   | Invalid_address _ -> (Ip.null, 0, zero)
 
@@ -956,16 +956,17 @@ let clean_join_queue_tables () =
 
 let client_public_key = ref ""
 
+
 let _ =
   option_hook client_private_key (fun _ ->
-    client_public_key := Unix32.load_key (!!client_private_key);
-
+    if Autoconf.donkey_sui = "yes" then begin
+    client_public_key := DonkeySui.SUI.load_key (!!client_private_key);
     (
     let key_checked = ref false in
     let key_check_again = ref false in
     let rec check_client_private_key () =
       key_checked := true;
-      if not (String.sub !!client_private_key 0 5 = "MIIBC") then
+      if not (try String.sub !!client_private_key 0 4 = "MIIB" with e -> false) then
         if !key_check_again then
 	  begin
 	    lprintf_nl () "can not create proper client_private_key, exiting...";
@@ -974,7 +975,7 @@ let _ =
 	else
           begin
             lprintf_nl () "bad client_private_key detected, creating new key";
-	    set_simple_option donkey_ini "client_private_key" (Unix32.create_key ());
+	    set_simple_option donkey_ini "client_private_key" (DonkeySui.SUI.create_key ());
 	    key_check_again := true
 	  end
     in
@@ -985,6 +986,7 @@ let _ =
 	check_client_private_key ()
       end
     );
+    end
   )
 
 let server_accept_multiple_getsources s =
