@@ -265,8 +265,6 @@ let really_query_download filenames size md4 location old_file absents =
 (*  !file_change_hook file; *)
 (*  set_file_size file (file_size file); *)
 
-  DonkeyNeighbours.recover_downloads [file];
-
   List.iter (fun s ->
       add_query_location file s
   ) (connected_servers());
@@ -412,10 +410,8 @@ let import_temp temp_dir =
                     size := v
                 | _ -> ()
             ) f.P.tags;
-            let _ = query_download !filenames !size f.P.md4 None
-              (Some filename) (Some (List.rev f.P.absents)) true;
-            in
-            ()
+            ignore (really_query_download !filenames !size f.P.md4 None
+              (Some filename) (Some (List.rev f.P.absents)));
       with _ -> ()
   ) list
 
@@ -533,8 +529,47 @@ let recover_md4s md4 =
 
 
 let parse_donkey_url url =
-  match String2.split ((*String.escaped*) url) '|' with
+  let url = Str.global_replace (Str.regexp "|sources,") "|sources|" url in
+  match String2.split (String.escaped url) '|' with
 (* TODO RESULT *)
+  | "ed2k://" :: "file" :: name :: size :: md4 :: "/" :: "sources" :: sources :: _
+  | "file" :: name :: size :: md4 :: "/" :: "sources" :: sources :: _ ->
+(*  ed2k://|file|Wikipedia_3.3_noimages.iso|2666311680|747735CD46B61DA92973E9A8840A9C99|/|sources,62.143.4.124:4662|/  *)
+      if Int64.of_string size >= 4294967295L then
+	"Files > 4GB are not allowed", false
+      else
+        begin
+	  let md4 = if String.length md4 > 32 then
+            String.sub md4 0 32 else md4 in
+	  let new_sources = ref [] in
+          let s = String2.split sources ',' in
+            List.iter (fun s ->
+              begin try
+	        match String2.split s ':' with
+                 [ip;port] ->
+                    let source_ip = Ip.of_string ip in
+                    let source_port = int_of_string port in
+		    new_sources := (source_ip, source_port) :: !new_sources
+	        | _ -> ()
+	      with _ -> ()
+          end) s;
+          begin
+	    try
+              let file = query_download [name] (Int64.of_string size)
+                (Md4.of_string md4) None None None false in
+	      let new_file = find_file (Md4.of_string md4) in
+	      CommonInteractive.start_download file;
+	      if !new_sources <> [] then
+	        begin
+	          List.iter (fun (source_ip, source_port) ->
+    		    add_source new_file source_ip source_port Ip.null 0
+    	          ) !new_sources;
+    	          (Printf.sprintf "added %d sources to new download" (List.length !new_sources)), true
+    	        end
+    	      else "", true
+    	    with e -> (Printexc2.to_string e), false
+    	  end
+    	end
   | "ed2k://" :: "file" :: name :: size :: md4 :: _
   | "file" :: name :: size :: md4 :: _ ->
       if Int64.of_string size >= 4294967295L then
@@ -556,8 +591,7 @@ let parse_donkey_url url =
             CommonInteractive.start_download file;
             "", true
           with e ->
-            let s = Printf.sprintf "%s" (Printexc2.to_string e) in
-	      s, false
+            (Printexc2.to_string e), false
           end
   | "ed2k://" :: "server" :: ip :: port :: _
   | "server" :: ip :: port :: _ ->
@@ -661,7 +695,7 @@ let commands = [
         with e ->
             Printf.sprintf "error %s while loading temp files" (
               Printexc2.to_string e)
-    ), "<temp_dir> :\t\t\timport the old edonkey temp directory";
+    ), "<temp_dir> :\t\timport the old edonkey temp directory";
 
 (*
     "load_old_history", Arg_none (fun o ->
@@ -690,7 +724,7 @@ let commands = [
     end
   else
     Printf.sprintf "ED2K_update_server_list_met is disabled, ignoring..."
-    ), "<filename|URL> :\t\t\tadd the servers from a server.met file or URL";
+    ), "<filename|URL> :\t\tadd the servers from a server.met file or URL";
 
     "id", Arg_none (fun o ->
         let buf = o.conn_buf in
@@ -941,9 +975,9 @@ parent.fstatus.location.href='submit?q=rename+'+i+'+\\\"'+encodeURIComponent(for
 
     "reset_md4", Arg_none (fun _ ->
         set_simple_option donkey_ini "client_md4" (Md4.to_string (mldonkey_md4 (Md4.random ())));
-        set_simple_option donkey_ini "client_private_key" (Unix32.create_key ());
+        if Autoconf.donkey_sui = "yes" then set_simple_option donkey_ini "client_private_key" (DonkeySui.SUI.create_key ());
         "reset client_md4/client_private_key"
-    ), ":\t\t\t\t\treset client_md4/client_private_key to random values";
+    ), ":\t\t\t\treset client_md4/client_private_key to random values";
 
     "bp", Arg_multiple (fun args o ->
         List.iter (fun arg ->
@@ -951,13 +985,7 @@ parent.fstatus.location.href='submit?q=rename+'+i+'+\\\"'+encodeURIComponent(for
             port_black_list =:=  port :: !!port_black_list;
         ) args;
         "done"
-    ), "<port1> <port2> ... :\t\t\tadd these Ports to the port black list";
-
-    "send_servers", Arg_none (fun o ->
-        CommonWeb.connect_redirector ();
-        "done"
-    ), ":\t\t\t\tsend the list of connected servers to the redirector";
-
+    ), "<port1> <port2> ... :\t\tadd these ports to the port black list";
   ]
 
 let _ =
@@ -1114,8 +1142,7 @@ let get_ips_cc_cn c =
     match c.client_kind with
       Direct_address (ip,port) -> 
         let cc,cn = Geoip.get_country ip in
-        Printf.sprintf "%s" (Ip.to_string ip)
-        ,cc,cn
+        (Ip.to_string ip),cc,cn
     | _ ->  
         let cc,cn = !Geoip.unknown_country in
         (string_of_client_addr c),cc,cn
@@ -1129,8 +1156,8 @@ let _ =
         P.client_network = network.network_num;
         P.client_kind = (match c.client_kind with
             Direct_address (ip, port) -> Known_location (ip,port)
-	  | Indirect_address (server_ip, server_port, ip, port) -> 
-	      Indirect_location (c.client_name,c.client_md4, ip_of_id ip, port)
+	  | Indirect_address (server_ip, server_port, ip, port, real_ip) -> 
+	      Indirect_location (c.client_name,c.client_md4, real_ip, port)
           | _ -> Indirect_location (c.client_name,c.client_md4, Ip.null, 0));
         P.client_state = client_state c;
         P.client_type = client_type c;
@@ -1372,7 +1399,7 @@ parent.fstatus.location.href='submit?q=rename+%d+\\\"'+encodeURIComponent(formID
           html_mods_td buf ([
             ("", "sr", (match c.client_download with
                   None -> ""
-                | Some _ -> Printf.sprintf "%s" (
+                | Some _ -> (
                       let qfiles = c.client_file_queue in
                       let (qfile, qchunks,_) =  List.hd qfiles in
                       if (qfile == file) then
