@@ -62,8 +62,7 @@ let hourly_timer timer =
   DonkeyClient.clean_groups ();
   DonkeyClient.clean_requests ();
   Hashtbl.clear udp_servers_replies;
-  DonkeyThieves.clean_thieves ();
-  DonkeyNeighbours.recover_downloads !current_files
+  DonkeyThieves.clean_thieves ()
     
 let quarter_timer timer =
   clean_join_queue_tables ()
@@ -79,7 +78,13 @@ let second_timer timer =
         if !verbose_sources > 2 then 
           lprintf_nl () "Exception %s while checking sources" 
             (Printexc2.to_string e)
-  )
+  );
+  DonkeyServers.udp_walker_timer ()
+
+let five_second_timer timer =
+  DonkeyServers.walker_timer ();
+  DonkeyOneFile.check_files_downloaded ();
+  DonkeyShare.check_shared_files ()
 
 let min_timer timer =
   DonkeySources.clean_sources (); (* Moved here from fivemin_timer. *)
@@ -183,8 +188,9 @@ let enable () =
     let enabler = ref true in
     is_enabled := true;
     network.op_network_disable <- disable enabler;
+    if Autoconf.donkey_sui = "yes" then
     (try
-      client_public_key := Unix32.load_key (!!client_private_key)
+      client_public_key := DonkeySui.SUI.load_key (!!client_private_key)
     with _ -> ());
     if not !!enable_donkey then enable_donkey =:= true;
     
@@ -294,8 +300,10 @@ be useful when users want to share files that they had already previously
       
       Options.option_hook global_login reset_tags;
       Options.option_hook login reset_tags;
-      Options.option_hook enable_sui reset_tags;
-
+      Options.option_hook enable_sui ( fun _ ->
+	if Autoconf.donkey_sui = "no" && !!enable_sui then enable_sui =:= false;
+	reset_tags ());
+				
 (**** START TIMERS ****)
       add_session_option_timer enabler check_client_connections_delay 
         (fun _ ->
@@ -308,19 +316,14 @@ be useful when users want to share files that they had already previously
       
       add_session_option_timer enabler check_connections_delay 
         DonkeyServers.check_server_connections;
-      add_session_option_timer enabler compute_md4_delay 
-        (fun _ ->
-          DonkeyOneFile.check_files_downloaded ();
-          DonkeyShare.check_shared_files ()
-      );
-      add_session_timer enabler 5.0 DonkeyServers.walker_timer;
-      add_session_timer enabler 1.0 DonkeyServers.udp_walker_timer;
+
       
       add_session_timer enabler 3600. hourly_timer;
       add_session_timer enabler 60. min_timer;
       add_session_timer enabler 300. fivemin_timer;
       add_session_timer enabler 900. quarter_timer;
       add_session_timer enabler 1. second_timer;
+      add_session_timer enabler 5. five_second_timer;
       add_session_option_timer enabler remove_old_servers_delay 
           DonkeyServers.remove_old_servers;
 
