@@ -78,14 +78,6 @@ let local_index_add_cmd = define_expert_option donkey_section
     string_option "" (* (cmd_basedir ^ "local_index_add") *)
 *)
 
-let compute_md4_delay = define_expert_option donkey_section ["compute_md4_delay"]
-    "The delay between computations of the md4 of chunks"
-  float_option 1.
-
-let _ =
-  option_hook compute_md4_delay (fun _ ->
-      if !!compute_md4_delay < 0.1 then compute_md4_delay =:= 0.1)
-
 let server_black_list = define_option donkey_section
     ["server_black_list"] "A list of server IP to remove from server list.
     Servers on this list can't be added, and will eventually be removed"
@@ -161,7 +153,7 @@ let client_md4 = define_option donkey_section ["client_md4"]
     "The MD4 of this client" Md4.option (mldonkey_md4 (Md4.random ()))
 
 let client_private_key = define_option donkey_section ["client_private_key"]
-    "The RSA private key of this client" string_option (Unix32.create_key ())
+    "The RSA private key of this client" string_option (DonkeySui.SUI.create_key ())
 
 let enable_sui = define_option donkey_section ["enable_sui"]
     "Enable secure user identification support" bool_option true
@@ -206,11 +198,6 @@ let dynamic_upload_threshold =
     "Uploaded zones (1 zone = 180 kBytes) needed to enable the dynamic upload lifetime"
     int_option 10
 
-let random_order_download =
-  define_option donkey_section ["random_order_download"]
-  "Should we try to download chunks in random order (false = linearly) ?"
-    bool_option true
-
 let connected_server_timeout =
   define_expert_option donkey_section ["connected_server_timeout"]
     "How long can a silent server stay connected"
@@ -329,7 +316,6 @@ let gui_donkey_options_panel =
     "Max Sources Per Download", shortname max_sources_per_file, "T";
     "Port", shortname donkey_port, "T";
     "Login", shortname login, "T";
-    "Download Chunks in Random order", shortname random_order_download, "B";
     "Sources Per Chunk", shortname sources_per_chunk, "T";
     "Prevent Re-download of Cancelled Files", shortname keep_cancelled_in_old_files, "B";
     "Prevent Re-download of Downloaded Files", shortname keep_downloaded_in_old_files, "B";
