@@ -90,7 +90,7 @@ let client_send c m =
       lprintf_nl () "Sent to client[%d] %s(%s) %s" (client_num c)
         c.client_name (brand_to_string c.client_brand)
       (match c.client_kind with
-          Indirect_address (server_ip, server_port, ip, port) ->
+          Indirect_address (server_ip, server_port, ip, port, real_ip) ->
 	    Printf.sprintf "[%s:%d]" (Ip.to_string (ip_of_id ip)) port
         | Direct_address (ip,port) -> Printf.sprintf "[%s:%d]" (Ip.to_string ip) port
         | Invalid_address _ -> ""
@@ -119,10 +119,6 @@ let servers_send socks m =
   List.iter (fun s -> write_string s m) socks
 
 let client_handler2 c ff f =
-  let emule_version = match !c with
-      None -> emule_proto ();
-    | Some c -> c.client_emule_proto
-  in
   let msgs = ref 0 in
   fun sock nread ->
 
@@ -130,6 +126,10 @@ let client_handler2 c ff f =
     let b = TcpBufferedSocket.buf sock in
     try
       while b.len >= 5 do
+        let emule_version = match !c with
+            None -> emule_proto ();
+          | Some c -> c.client_emule_proto
+        in
         let opcode = get_uint8 b.buf b.pos in
         let msg_len = get_int b.buf (b.pos+1) in
         if b.len >= 5 + msg_len then
@@ -398,6 +398,27 @@ let client_send_files sock msg =
   str_int s 6 nfiles;
   write_string sock s
 
+let client_send_dir sock dir files =
+  let max_len = !!client_buffer_size - 100 -
+    TcpBufferedSocket.remaining_to_write sock in
+  Buffer.reset buf;
+  buf_int8 buf 227;
+  buf_int buf 0;
+  buf_int8 buf 96; (* ViewFilesDirReply *)
+  buf_string buf dir;
+  buf_int buf 0;
+  let pos = Buffer.length buf in
+  let nfiles, prev_len = DonkeyProtoClient.ViewFilesReply.write_files_max buf (
+      make_tagged (Some sock) files)
+    0 max_len in
+  let s = Buffer.contents buf in
+  let s = String.sub s 0 prev_len in
+  let len = String.length s - 5 in begin
+    str_int s 1 len;
+    str_int s (pos-4) nfiles;
+  end;
+  write_string sock s
+
 let udp_server_send s t =
   udp_send (get_udp_sock ()) s.server_ip (s.server_port+4) t
 
