@@ -35,6 +35,13 @@ open DonkeyOptions
 
 module P = struct
 
+    let lprintf_nl () =
+      lprintf "%s[Kademlia] "
+      (log_time ()) ; lprintf_nl2
+
+    let lprintf_n () =
+      lprintf "[Kademlia] " ; lprintf
+
     let names_of_tag =
       [
         "\248", Field_UNKNOWN "buddyhash"; (* 0xF8 *)
@@ -219,15 +226,16 @@ module P = struct
       let ip = get_ip s (pos+16) in
       let udp_port = get_int16 s (pos + 20) in
       let tcp_port = get_int16 s (pos + 22) in
-      let kind = get_uint8 s (pos + 24) in
+(*       let kind = get_uint8 s (pos + 24) in *)
       {
         peer_md4 = md4;
         peer_ip = ip;
         peer_port = udp_port;
         peer_tcpport = tcp_port;
-        peer_kind = kind;
-        peer_last_recv = 0;
+        peer_kind = 3;
         peer_last_send = 0;
+        peer_expire = 0;
+        peer_created = last_time ();
       }, pos + 25
 
     let get_peers_from_results ip port answers =
@@ -250,10 +258,10 @@ module P = struct
                   )
               | Field_UNKNOWN "sourcetype" ->
                   for_int_tag tag (fun kind ->
-                      peer_kind := kind)
+                      peer_kind := 3)
               | _ ->
                 if !verbose_unknown_messages then
-                  lprintf_nl "[Kademlia] Unused source tag [%s]"
+                  lprintf_nl () "Unused source tag [%s]"
                     (escaped_string_of_field tag)
           ) r_tags;
           {
@@ -261,9 +269,10 @@ module P = struct
             peer_port = !peer_udpport;
             peer_tcpport = !peer_tcpport;
             peer_md4 = r_md4;
-            peer_last_recv = 0;
             peer_last_send = 0;
-            peer_kind = !peer_kind;
+            peer_expire = 0;
+            peer_kind = 3;
+            peer_created = last_time ();
           }
       ) answers
 
@@ -274,7 +283,7 @@ module P = struct
           OvernetConnect p
 
       | 0x08 ->
-          let n = get_int16 s 0 in
+(*	  let n = get_int16 s 0 in *)
           let peers, pos = get_list16 get_peer s 0 in
           OvernetConnectReply peers
 
@@ -394,7 +403,7 @@ module P = struct
           magic <> kademlia_packed_header_code) then
         begin
           if !CommonOptions.verbose_unknown_messages then begin
-              lprintf_nl "Received unknown UDP packet";
+              lprintf_nl () "Received unknown UDP packet";
               dump pbuf;
             end;
           raise Not_found
@@ -416,7 +425,7 @@ module P = struct
 
     let udp_send sock ip port ping msg =
       try
-        Buffer.clear udp_buf;
+        Buffer.reset udp_buf;
         write udp_buf msg;
         let s = Buffer.contents udp_buf in
 
@@ -431,10 +440,8 @@ module P = struct
 
         if !verbose_overnet then
           begin
-            lprintf_nl "[Kademlia] Sending UDP to %s:%d type %s (opcode 0x%02X len %d)"
-              (Ip.to_string ip) port (message_to_string msg) (get_uint8 s 1)
-            (String.length s);
-(*dump s; lprint_newline ();*)
+            lprintf_nl () "Sending UDP to %s:%d (opcode 0x%02X len %d) type %s"
+              (Ip.to_string ip) port (get_uint8 s 1) (String.length s) (message_to_string msg);
           end;
         (*
         let len = String.length s in
@@ -447,7 +454,7 @@ module P = struct
         UdpSocket.write sock ping s ip port
       with
       | MessageNotImplemented -> ()
-      | e -> lprintf_nl "[Kademlia] Exception %s in udp_send" (Printexc2.to_string e)
+      | e -> lprintf_nl () "Exception %s in udp_send" (Printexc2.to_string e)
 
     let udp_handler f sock event =
       match event with
@@ -467,7 +474,7 @@ module P = struct
               with e ->
                 if !verbose_unknown_messages then
                 begin
-                  lprintf_nl "[Kademlia] Error %s in udp_handler, dump of packet:"
+                  lprintf_nl () "Error %s in udp_handler, dump of packet:"
                     (Printexc2.to_string e);
                   dump p.UdpSocket.udp_content;
                   lprint_newline ()
@@ -475,6 +482,8 @@ module P = struct
           );
       | _ -> ()
 
+    let checking_kind_timeout = 120
+
     let redirector_section = "DKKA"
     let options_section_name = "Kademlia"
 
