@@ -32,7 +32,14 @@ open DonkeyOvernet
 
 module Proto = struct
 
-    let names_of_tag = file_common_tags
+     let lprintf_nl () =
+      lprintf "%s[Overnet] "
+      (log_time ()) ; lprintf_nl2
+
+    let lprintf_n () =
+      lprintf "[Overnet] " ; lprintf
+
+   let names_of_tag = file_common_tags
 
     let buf_peer buf p =
       buf_md4 buf p.peer_md4;
@@ -44,15 +51,16 @@ module Proto = struct
       let md4 = get_md4 s pos in
       let ip = get_ip s (pos+16) in
       let port = get_int16 s (pos+20) in
-      let kind = get_uint8 s (pos+22) in
+(*      let kind = get_uint8 s (pos+22) in *)
       {
         peer_md4 = md4;
         peer_ip = ip;
         peer_port = port;
         peer_tcpport = 0;
-        peer_kind = kind;
-        peer_last_recv = 0;
+        peer_kind = 3;
         peer_last_send = 0;
+        peer_expire = 0;
+        peer_created = last_time ();
       }, pos + 23
 
     let write buf t =
@@ -176,20 +184,19 @@ module Proto = struct
       let peer_ip = ref ip in
       let peer_udpport = ref port in
       let peer_tcpport = ref 0 in
-      let peer_kind = ref 0 in
       List.iter (fun tag ->
           match tag.tag_name with
             Field_UNKNOWN "loc" ->
               for_string_tag tag (fun bcp ->
                   if !verbose_overnet then
-                  lprintf_nl "loc tag : [%s]" bcp;
+                  lprintf_nl () "loc tag : [%s]" bcp;
                   if String2.starts_with bcp "bcp://" then
                     let bcp2 = String.sub bcp 6 (String.length bcp - 6)
                     in
                     match String2.split_simplify bcp2 ':' with
                     | [_;ip;port] ->
                         if !verbose_overnet then
-                          lprintf_nl "[Overnet] Received BCP type 2 %s"
+                          lprintf_nl () "Received BCP type 2 %s"
                             bcp;
 
 (* FIXME: A firewalled peer...
@@ -202,14 +209,14 @@ module Proto = struct
                         peer_tcpport := int_of_string port;
                     | _ ->
         		if !verbose_overnet then
-                          lprintf_nl "[Overnet] Ill formed bcp: [%s]" bcp;
+                          lprintf_nl () "Ill formed bcp: [%s]" bcp;
                   else
 		    if !verbose_overnet then
-                      lprintf "[Overnet] Ill formed bcp: [%s]" bcp;
+                      lprintf_nl () "Ill formed bcp: [%s]" bcp;
               )
           | _ ->
             if !verbose_unknown_messages then
-              lprintf_nl "[Overnet] Unused source tag [%s]"
+              lprintf_nl () "Unused source tag [%s]"
                 (escaped_string_of_field tag)
       ) r_tags;
       {
@@ -217,9 +224,10 @@ module Proto = struct
           peer_port = !peer_udpport;
           peer_tcpport = !peer_tcpport;
           peer_md4 = r_md4;
-          peer_last_recv = 0;
           peer_last_send = 0;
-          peer_kind = !peer_kind;
+          peer_expire = 0;
+          peer_kind = 3;
+          peer_created = last_time ();
         }
 
     let parse ip port opcode s =
@@ -229,15 +237,16 @@ module Proto = struct
             let md4 = get_md4 s 0 in
             let ip = get_ip s 16 in
             let port = get_int16 s 20 in
-            let kind = get_uint8 s 22 in
+(*	    let kind = get_uint8 s 22 in *)
             OvernetConnect {
               peer_md4 = md4;
               peer_ip = ip;
               peer_port = port;
-              peer_kind = kind;
+              peer_kind = 3;
               peer_tcpport = 0;
-              peer_last_recv = 0;
               peer_last_send = 0;
+              peer_expire = 0;
+              peer_created = last_time ();
             }
         | 11 ->
             let peers, pos = get_list16 get_peer s 0 in
@@ -246,15 +255,16 @@ module Proto = struct
             let md4 = get_md4 s 0 in
             let ip = get_ip s 16 in
             let port = get_int16 s 20 in
-            let kind = get_uint8 s 22 in
+(*	    let kind = get_uint8 s 22 in *)
             OvernetPublicize {
               peer_md4 = md4;
               peer_ip = ip;
               peer_port = port;
-              peer_kind = kind;
+              peer_kind = 3;
               peer_tcpport = 0;
-              peer_last_recv = 0;
               peer_last_send = 0;
+              peer_expire = 0;
+              peer_created = last_time ();
             }
         | 13 ->
             OvernetPublicized None
@@ -307,7 +317,7 @@ module Proto = struct
         | 21 ->
 (* idem as 33, but IP seem to be a low ID *)
             if !verbose_overnet then begin
-                lprintf_nl "Received code %d message.\nDump:" opcode;
+                lprintf_nl () "Received code %d message. Dump:" opcode;
                 dump s;
                 lprint_newline ();
               end;
@@ -315,50 +325,50 @@ module Proto = struct
             OvernetUnknown21 peer
         | 24 ->
             if !verbose_overnet then
-              lprintf_nl "RCVD: OVERNET FIREWALL CONNECTION (24)";
+              lprintf_nl () "RCVD: OVERNET FIREWALL CONNECTION (24)";
             let md4 = get_md4 s 0 in
             let port = get_int16 s 16 in
             OvernetFirewallConnection(md4,port)
         | 25 ->
             if !verbose_overnet then
-              lprintf_nl "RCVD: OVERNET FIREWALL CONNECTION ACK (25)";
+              lprintf_nl () "RCVD: OVERNET FIREWALL CONNECTION ACK (25)";
             let md4 = get_md4 s 0 in
             OvernetFirewallConnectionACK(md4)
         | 26 ->
             if !verbose_overnet then
-              lprintf_nl "RCVD: OVERNET FIREWALL CONNECTION NACK (26)";
+              lprintf_nl () "RCVD: OVERNET FIREWALL CONNECTION NACK (26)";
             let md4 = get_md4 s 0 in
             OvernetFirewallConnectionNACK(md4)
         | 27 ->
             if !verbose_overnet then
-              lprintf_nl "RCVD: GETMYIP MESSAGE (27)";
+              lprintf_nl () "RCVD: GETMYIP MESSAGE (27)";
             OvernetGetMyIP (get_int16 s 0)
         | 28 ->
             if !verbose_overnet then
-              lprintf_nl "RCVD: GETMYIPRESULT MESSAGE (28)";
+              lprintf_nl () "RCVD: GETMYIPRESULT MESSAGE (28)";
             let ip = get_ip s 0 in
             OvernetGetMyIPResult (ip)
         | 29 ->
             if !verbose_overnet then
-              lprintf_nl "RCVD: GETMYIPDONE MESSAGE (29)";
+              lprintf_nl () "RCVD: GETMYIPDONE MESSAGE (29)";
             OvernetGetMyIPDone
         | 33 ->
             if !verbose_overnet then
-              lprintf_nl "RCVD: PEER NOT FOUND (33)";
+              lprintf_nl () "RCVD: PEER NOT FOUND (33)";
             let peer, _ = get_peer s 0 in
             OvernetPeerNotFound peer
         | _ ->
             if !verbose_unknown_messages then
               begin
-                lprintf_nl "[Overnet] unknown opcode %d" opcode;
+                lprintf_nl () "unknown opcode %d" opcode;
                 dump s;
                 lprint_newline ();
               end;
             OvernetUnknown (opcode, s)
       with e ->
-          if !verbose_hidden_errors then
+          if !verbose_unknown_messages then
             begin
-              lprintf_nl "Error %s while parsing opcode %d" (Printexc2.to_string e) opcode;
+              lprintf_nl () "Error %s while parsing opcode %d" (Printexc2.to_string e) opcode;
               dump s;
               lprint_newline ();
             end;
@@ -375,7 +385,7 @@ module Proto = struct
                   int_of_char pbuf.[0] <> 227 then
                   begin
                     if !verbose_unknown_messages then begin
-                        lprintf_nl "[Overnet] Received unknown UDP packet";
+                        lprintf_nl () "Received unknown UDP packet";
                         dump pbuf;
                       end
                   end
@@ -393,7 +403,7 @@ module Proto = struct
                   end
               with e ->
                 if !verbose_unknown_messages then begin
-                  lprintf_nl "[Overnet] Error %s in udp_handler, dump of packet:"
+                  lprintf_nl () "Error %s in udp_handler, dump of packet:"
                     (Printexc2.to_string e);
                   dump p.UdpSocket.udp_content;
                   lprint_newline ()
@@ -401,6 +411,8 @@ module Proto = struct
           );
       | _ -> ()
 
+    let checking_kind_timeout = 180
+
     let redirector_section = "DKKO"
     let options_section_name = overnet_options_section_name
     let overnet_section = overnet_section
@@ -411,21 +423,18 @@ module Proto = struct
 
     let udp_send sock ip port ping msg =
       try
-        Buffer.clear udp_buf;
+        Buffer.reset udp_buf;
         buf_int8 udp_buf 227;
         write udp_buf msg;
         let s = Buffer.contents udp_buf in
         if !verbose_overnet then
           begin
-            lprintf_nl "Sending UDP to %s:%d (0x%02X)"
-              (Ip.to_string ip) port (get_uint8 s 1);
-            lprintf_nl "  %s"  (message_to_string msg)
-(*dump s; lprint_newline ();*)
+            lprintf_nl () "Sending UDP to %s:%d (opcode 0x%02X len %d) type %s"
+              (Ip.to_string ip) port (get_uint8 s 1) (String.length s) (message_to_string msg);
           end;
-        let len = String.length s in
         UdpSocket.write sock ping s ip port
       with e ->
-          lprintf_nl "Exception %s in udp_send" (Printexc2.to_string e)
+          lprintf_nl () "Exception %s in udp_send" (Printexc2.to_string e)
 
     let udp_send sock ip port ping msg =
       match msg with
@@ -497,7 +506,7 @@ module Overnet = struct
             assert (port = !!overnet_port)
         | _ -> failwith "Bad socket address"
       with e ->
-          lprintf_nl "Could not assign TCP port %d for Overnet\n" !!overnet_port;
+          lprintf_nl "[Overnet] Could not assign TCP port %d for Overnet" !!overnet_port;
           tcp_sock := None
 
     let disable () =
