@@ -197,6 +197,8 @@ thread. Moreover, we don't want to open all the filedescs for all the
 files being shared !
 *)
 
+exception Wrong_file_size
+
 let computation = ref false
 
 (*   Compute (at most) one MD4 chunk if needed. *)
@@ -206,26 +208,18 @@ let check_shared_files () =
     match !shared_files with
       [] -> ()
     | sh :: files ->
-        shared_files := files;
-
-(*      lprintf "check_shared_files"; lprint_newline (); *)
-
         let rec job_creater _ =
           try
-            if not (Sys.file_exists sh.shared_name) then begin
-                lprintf_nl () "Shared file doesn't exist";
+            if not (Sys.file_exists sh.shared_name) then
                 raise Not_found;
-              end;
-            if Unix32.getsize sh.shared_name <> sh.shared_size then begin
-                lprintf_nl () "Bad shared file size";
-                raise Not_found;
-              end;
+            if Unix32.getsize sh.shared_name <> sh.shared_size then
+                raise Wrong_file_size;
             computation := true;
             let end_pos = sh.shared_pos ++ block_size in
             let end_pos = if end_pos > sh.shared_size then sh.shared_size
               else end_pos in
             let len = end_pos -- sh.shared_pos in
-(*          lprintf "compute next md4"; lprint_newline (); *)
+            if !verbose_md4 then lprintf_nl () "compute next md4 of %s" sh.shared_name;
 
             M.compute_md4 (Unix32.filename sh.shared_fd) sh.shared_pos len
               (fun job ->
@@ -234,7 +228,7 @@ let check_shared_files () =
                     lprintf_nl () "Error prevent sharing %s" sh.shared_name
                   end else
                 let _ = () in
-(*              lprintf "md4 computed"; lprint_newline (); *)
+		if !verbose_md4 then lprintf_nl () "computed md4 of %s" sh.shared_name;
                 let new_md4 = job.M.job_result in
 
                 sh.shared_list <- new_md4 :: sh.shared_list;
@@ -250,13 +244,15 @@ let check_shared_files () =
                     Hashtbl.add shared_files_info
                       (s.sh_name, s.sh_size, s.sh_mtime) s;
                     known_shared_files =:= s :: !!known_shared_files;
-                    new_file_to_share s sh.shared_shared.impl_shared_codedname (Some  sh.shared_shared);
+		    shared_files := files;
+                    new_file_to_share s sh.shared_shared.impl_shared_codedname (Some sh.shared_shared);
                   end
                 else
                   job_creater ())
           with e ->
-              lprintf_nl () "Exception %s prevents sharing"
-                (Printexc2.to_string e);
+	      shared_files := files;
+              lprintf_nl () "Exception %s prevents sharing of %s"
+                (Printexc2.to_string e) sh.shared_name
         in
         job_creater ()
 
@@ -284,19 +280,12 @@ lprintf "Searching %s" fullname; lprint_newline ();
             raise Not_found
           end *)
       with Not_found ->
-          if !verbose_share then begin
+          if !verbose_share then
               lprintf_nl () "donkeyShare: No info on %s" fullname;
-            end;
-
-          let rec iter list left =
-            match list with
-              [] -> List.rev left
-            | sh :: tail ->
-                if sh.shared_name = fullname then iter tail left
-                else iter tail (sh :: left)
-          in
-          shared_files := iter !shared_files [];
 
+	  let found = ref false in
+	  List.iter (fun sh -> if sh.shared_name = fullname then found := true) !shared_files;
+	  if not !found then begin
           let rec impl = {
               impl_shared_update = 1;
               impl_shared_fullname = fullname;
@@ -319,6 +308,7 @@ lprintf "Searching %s" fullname; lprint_newline ();
             } in
           update_shared_num impl;
           shared_files := pre_shared :: !shared_files;
+	  end
   )
 
 let remember_shared_info file new_name =
