@@ -474,7 +474,7 @@ let brand_mod_to_int brand =
 
 type source_uid =
   Direct_address of Ip.t * int
-| Indirect_address of Ip.t * int * int64 * int
+| Indirect_address of Ip.t * int * int64 * int * Ip.t
 | Invalid_address of string * string
 
 let id_of_ip ip = Ip.to_int64 (Ip.rev ip)
@@ -513,7 +513,7 @@ module DonkeySources = CommonSources.Make(struct
             let port = value_to_int port in
             let id = try id_of_ip (Ip.of_string (value_to_string id))
               with _ -> value_to_int64 id in
-            Indirect_address (ip, port, id, port)
+            Indirect_address (ip, port, id, 0, Ip.null)
         | _ ->
             failwith "bad client address"
 
@@ -521,7 +521,7 @@ module DonkeySources = CommonSources.Make(struct
         match s with
           Direct_address (ip, port) ->
             SmallList [string_to_value (Ip.to_string ip); int_to_value port]
-        | Indirect_address (server_ip, server_port, id, port) ->
+        | Indirect_address (server_ip, server_port, id, port, _) ->
             SmallList [
               string_to_value (Ip.to_string server_ip);
               int_to_value server_port;
