@@ -44,6 +44,16 @@ open FasttrackNetwork
 open FasttrackTypes
 open FasttrackOptions
 
+(* prints a new logline with date, module and starts newline *)
+let lprintf_nl () =
+  lprintf "%s[Fasttrack] "
+    (log_time ()); lprintf_nl2
+
+(* prints a new logline with date, module and does not start newline *)
+let lprintf_n () =
+  lprintf "%s[Fasttrack] "
+    (log_time ()); lprintf
+
 let search_num = ref 0
 
 let should_update_shared_files = ref false
@@ -78,7 +88,7 @@ let as_file file = as_file file.file_file
 let file_size file = file.file_file.impl_file_size
 let file_downloaded file = file_downloaded (as_file file)
 let file_age file = file.file_file.impl_file_age
-let file_fd file = file.file_file.impl_file_fd
+let file_fd file = file_fd (as_file file)
 let file_disk_name file = file_disk_name (as_file file)
 let file_state file =
   file_state (as_file file)
@@ -256,11 +266,9 @@ let new_file file_temporary file_name file_size file_hash =
   let t = Unix32.create_rw file_temp in
   let file_chunk_size =
     max megabyte (
-      file_size // (max (Int64.of_int 5) (file_size // (megabytes 5)))
+      file_size // (max 5L (file_size // (megabytes 5)))
     )
   in
-  let keywords = CommonUploads.words_of_filename file_name in
-  let words = String2.unsplit keywords ' ' in
   let uid = Uid.create (Md5Ext file_hash) in
   let rec file = {
       file_file = file_impl;
@@ -276,7 +284,7 @@ let new_file file_temporary file_name file_size file_hash =
       file_ttr = None;
     } and file_impl =  {
       dummy_file_impl with
-      impl_file_fd = t;
+      impl_file_fd = Some t;
       impl_file_size = file_size;
       impl_file_downloaded = Int64.zero;
       impl_file_val = file;
@@ -347,7 +355,7 @@ let new_user kind =
           user_user = user_impl;
           user_uid = (match kind with
               Known_location _ -> Md4.null
-            | Indirect_location (_, uid) -> uid);
+            | Indirect_location (_, uid, _, _) -> uid);
           user_kind = kind;
 (*          user_files = []; *)
           user_speed = 0;
@@ -500,3 +508,12 @@ let client_name () =
       String2.replace_char !ft_client_name ' ' '_';
     end;
   !ft_client_name
+
+(*************************************************************
+ Define a function to be called when the "mem_stats" command
+   is used to display information on structure footprint.
+**************************************************************)
+
+let _ =
+  Heap.add_memstat "FasttrackGlobals" (fun level buf ->
+     Printf.bprintf buf "Number of old files: %d\n" (List.length !!old_files))
