@@ -45,8 +45,8 @@ open FasttrackGlobals
 (*                                                                       *)
 (*************************************************************************)
 
-let int64_3 = Int64.of_int 3
-let int64_ffffffff = Int64.of_string "0xffffffff"
+let int64_3 = 3L
+let int64_ffffffff = 0xffffffffL
 let default_bandwidth = 0x68
 
 external fst_hash_checksum : string -> int = "fst_hash_checksum_ml"
@@ -914,7 +914,7 @@ dec: [(63)]
             let tag =
               try
                 List2.assoc_inv tag name_of_tag
-              with Not_found as e ->
+              with Not_found ->
                   lprintf "WARNING Unknown tag %d\n" tag;
                   Field_UNKNOWN (string_of_int tag)
             in
@@ -990,8 +990,7 @@ dec: [(63)]
             let my_port = get_int16 m 4 in
 
             let bandwidth = get_int8 m 6 in
-            let next_byte = get_int8 m 7 in
-
+(*	    let next_byte = get_int8 m 7 in *)
             let client_name = String.sub m 8 (String.length m - 8) in
 
             NodeInfoReq (my_ip, my_port, bandwidth, client_name)
@@ -1005,8 +1004,8 @@ dec: [(63)]
             let shared_size, pos = get_dynint m pos in
             let shared_tags, pos = get_tags m pos in
 
-            let computed_checksum = Int64.of_int
-                (fst_hash_checksum shared_hash) in
+            let computed_checksum = 
+              Int64.of_int (fst_hash_checksum shared_hash) in
             if computed_checksum <> shared_checksum then begin
                 lprintf "Bad COMPUTED checksum for hash\n";
               end;
@@ -1073,8 +1072,8 @@ dec: [(63)]
                 let result_checksum, pos = get_dynint m (pos+20) in
                 let result_size, pos = get_dynint m pos in
 
-                let computed_checksum = Int64.of_int
-                    (fst_hash_checksum result_hash) in
+                let computed_checksum = 
+                  Int64.of_int (fst_hash_checksum result_hash) in
                 if computed_checksum <> result_checksum then begin
                     lprintf "Bad COMPUTED checksum for hash\n";
                   end;
@@ -1174,7 +1173,6 @@ dec: [(63)]
             AskUDPConnectionReq (LittleEndian.get_ip m 0, get_int16 m 4)
 
         | 0x1d ->
-            let netname = m in
             NetworkNameReq m
 
         | 0x1e -> Unknown_1e (get_int m 0)
@@ -1257,8 +1255,8 @@ dec: [(63)]
             let shared_size, pos = get_dynint m pos in
             let shared_tags, pos = get_tags m pos in
 
-            let computed_checksum = Int64.of_int
-                (fst_hash_checksum shared_hash) in
+            let computed_checksum = 
+              Int64.of_int (fst_hash_checksum shared_hash) in
             if computed_checksum <> shared_checksum then begin
                 lprintf "Bad COMPUTED checksum for hash\n";
               end;
@@ -1892,7 +1890,7 @@ let resend_udp_packets _ = ()
 let check_primitives () =
   (try
       let cipher = create_cipher () in
-      set_cipher cipher (Int32.of_int 123456789) 0x29;
+      set_cipher cipher 123456789l 0x29;
       init_cipher cipher;
       let s = String.create 12 in
       cipher_packet_set cipher s 0;
@@ -1904,6 +1902,7 @@ let check_primitives () =
       lprintf "apply_cipher s = \"%s\"\n" (String.escaped s);
       cipher_free cipher;
     with _ ->
+	lprint_newline ();
         lprintf "The Fasttrack plugin will not work on your computer, since\n";
         lprintf "the encryption algorithm does not work correctly.\n";
         lprintf "You can try to solve this problem by hacking the C files in\n";
@@ -1917,7 +1916,6 @@ let translate_query q =
   let add_words w =
     keywords := (String2.split_simplify w ' ') @ !keywords
   in
-  let audio = ref false in
   let tags = ref [] in
   let rec iter q =
     match q with
