@@ -44,6 +44,16 @@ open GnutellaTypes
 open GnutellaOptions
 open GnutellaNetwork
 
+(* prints a new logline with date, module and starts newline *)
+let lprintf_nl () =
+  lprintf "%s[Gnutella] "
+    (log_time ()); lprintf_nl2
+
+(* prints a new logline with date, module and does not start newline *)
+let lprintf_n () =
+  lprintf "%s[Gnutella] "
+    (log_time ()); lprintf
+
 let should_update_shared_files = ref false
 
   
@@ -78,7 +88,7 @@ let as_file file = as_file file.file_file
 let file_size file = file.file_file.impl_file_size
 let file_downloaded file = file_downloaded (as_file file)
 let file_age file = file.file_file.impl_file_age
-let file_fd file = file.file_file.impl_file_fd
+let file_fd file = file_fd (as_file file)
 let file_disk_name file = file_disk_name (as_file file)
 let file_state file =  file_state (as_file file)
 let file_num file =  file_num (as_file file)
@@ -260,8 +270,7 @@ let new_result file_name file_size tags (uids : Uid.t list) sources =
             Hashtbl.add results_by_uid (Uid.to_uid uid) rs;
             rs
       in
-      let r = IndexedResults.get_result rs in
-(*
+(*      let r = IndexedResults.get_result rs in
       let rec iter_uid uid =
         if not (List.mem uid r.result_uids) then begin
             r.result_uids <- uid :: r.result_uids;
@@ -291,8 +300,6 @@ let megabytes10 = Int64.of_int (10 * 1024 * 1024)
 let new_file file_temporary file_name file_size file_uids = 
   let file_temp = Filename.concat !!temp_directory file_temporary in
   let t = Unix32.create_rw file_temp in
-  let keywords = CommonUploads.words_of_filename file_name in
-  let words = String2.unsplit keywords ' ' in
   let rec file = {
       file_file = file_impl;
       file_temp = file_temporary;
@@ -307,7 +314,7 @@ let new_file file_temporary file_name file_size file_uids =
       file_ttr = None;
     } and file_impl =  {
       dummy_file_impl with
-      impl_file_fd = t;
+      impl_file_fd = Some t;
       impl_file_size = file_size;
       impl_file_downloaded = Int64.zero;
       impl_file_val = file;
@@ -376,7 +383,7 @@ let new_user kind =
           user_user = user_impl;
           user_uid = (match kind with
               Known_location _ -> Md4.null
-            | Indirect_location (_, uid) -> uid);
+            | Indirect_location (_, uid, _, _) -> uid);
           user_kind = kind;
 (*          user_files = []; *)
           user_speed = 0;
@@ -576,4 +583,19 @@ let local_login () =
   let name = !!global_login in
   let len = String.length name in
   if len < 32 then name else  String.sub name 0 32
-    
+
+(*************************************************************
+
+Define a function to be called when the "mem_stats" command
+  is used to display information on structure footprint.
+
+**************************************************************)
+
+let _ =
+(*  let network_info = CommonNetwork.network_info network in *)
+  let name = network.network_name ^ "Globals" in
+  Heap.add_memstat name (fun level buf ->
+        Printf.bprintf buf "Number of old files: %d\n" (List.length !!old_files
+  )
+);
+
