@@ -157,6 +157,10 @@ let incoming_data_log = define_option gnutella_section
     ["incoming_data_log"]
     "(only for development tests)"
     string_option ""
+
+let options_version = define_option gnutella_section ["options_version"]
+    "(internal option)"
+    int_option 0
   
 let gui_gnutella_options_panel = 
   (*
@@ -174,4 +178,8 @@ let gui_gnutella_options_panel =
     
     "          Max Connected Ultrapeers", shortname max_ultrapeers, "T"; 
   ]
-  
+
+let old_files =
+  define_option gnutella_section ["old_files"]
+    "" (list_option (tuple2_option (string_option, int64_option))) []
+
