@@ -375,7 +375,7 @@ module QueryReply = struct (* QUERY_REPLY *)
       let files, pos  = iter_files nfiles s 11 [] in
       
       let vendor = String.sub s pos 4 in
-      let vendor_len = get_uint8 s (pos+4) in
+(*      let vendor_len = get_uint8 s (pos+4) in *)
       let byte5 = get_uint8 s (pos+5) in
       let byte6 = get_uint8 s (pos+6) in
       
@@ -506,7 +506,7 @@ let parse pkt =
     | UNKNOWN i ->  { pkt with pkt_payload = UnknownReq 
             (UNKNOWN i,pkt.pkt_payload) }
   with e ->
-      if !verbose_hidden_errors then
+      if !verbose_unknown_messages then
         begin
           lprintf "Exception in parse: %s\n" (Printexc2.to_string e);
           dump pkt.pkt_payload;
@@ -565,7 +565,7 @@ let server_msg_to_string pkt =
       lprintf "SENDING :\n";
       print pkt;
     end; 
-  Buffer.clear buf;
+  Buffer.reset buf;
   buf_md4 buf pkt.pkt_uid;
   buf_int8 buf (match pkt.pkt_type with
     | PING -> 0
@@ -618,7 +618,6 @@ let udp_send ip port msg =
   | Some sock ->
       try
         let s = server_msg_to_string msg in
-        let len = String.length s in
         if !verbose_msg_servers then begin
             lprintf "Sending on UDP to %s:%d:\n%s\n"
               (Ip.to_string ip) port
@@ -847,13 +846,10 @@ let send_qrt_sequence s update_table =
   let table = !cached_qrt_table in
   
   let compressor, table =
-    if Autoconf.has_zlib then
       1, 
       let t = Autoconf.zlib__compress_string table in
       assert (Autoconf.zlib__uncompress_string2 t = table);
       t
-    else
-      0, table 
   in
   
   server_send_qrt_patch s {
