@@ -135,7 +135,7 @@ let g2_packet_handler s sock gconn p =
         g2_payload = QKA; 
         g2_children = [
           {
-            g2_payload = QKA_QK (Int32.of_int 123456);
+            g2_payload = QKA_QK 123456l;
             g2_children = [];
           };
           {
@@ -149,8 +149,7 @@ let g2_packet_handler s sock gconn p =
   | QKA ->
       H.host_queue_add active_udp_queue h (last_time ());
       if (Queues.Queue.length active_udp_queue) > 100 then
-        let oh = H.host_queue_take active_udp_queue in
-        ();
+        ignore (H.host_queue_take active_udp_queue);
       List.iter (fun c ->
           match c.g2_payload with
             QKA_QK key -> s.server_query_key <- UdpQueryKey key
@@ -202,8 +201,7 @@ let g2_packet_handler s sock gconn p =
           
           | Q2_MD xml ->
               begin try
-                  let xml = Xml.parse_string xml in
-                  ()
+                  ignore (Xml.parse_string xml)
                 with e -> 
                     lprintf "Error %s parsing Xml \n%s\n"
                       (Printexc2.to_string e)
@@ -290,7 +288,7 @@ packet QH2_H (
           match c.g2_payload with
             KHL_NH (ip,port) 
           | KHL_CH ((ip,port),_) ->
-              let h = H.new_host (Ip.addr_of_ip ip) port Ultrapeer in ()
+              ignore (H.new_host (Ip.addr_of_ip ip) port Ultrapeer)
           | _ -> ()
       ) p.g2_children;
       let children = ref [] in
@@ -430,8 +428,8 @@ XML ("audios",
                   let xml = Xml.xml_of (Xml.parse_string xml) in
                   xml_info := Some xml
                 with e ->
-                    if !verbose_hidden_errors then
-                      lprintf "Exception %s while parsing: \n%s\n"
+                    if !verbose_unknown_messages then
+                      lprintf_nl () "Exception %s while parsing: \n%s"
                         (Printexc2.to_string e) xml
               
               end
@@ -452,8 +450,8 @@ XML ("audios",
                       tags)
                 ) user_files files
               end else begin
-                if !verbose_hidden_errors then
-                  lprintf "ERROR: Not enough XML entries %d/%d\n"
+                if !verbose_unknown_messages then
+                  lprintf_nl () "ERROR: Not enough XML entries %d/%d"
                     (List.length files) (List.length user_files);
                 user_files 
               end
@@ -475,7 +473,7 @@ XML ("audios",
       
       let user = 
         let user = new_user (match !user_addr with
-              None -> Indirect_location (!user_nick, !user_uid)
+              None -> Indirect_location (!user_nick, !user_uid, Ip.null, 0)
             | Some (ip,port) -> Known_location (ip,port))
         in
         (match !user_vendor with Some v -> user.user_vendor <- v | _ -> ());
