@@ -44,15 +44,10 @@ let ro_flag =  [Unix.O_RDONLY]
 let rw_flag =  [Unix.O_RDWR]
 let rw_creat_flag =  [Unix.O_CREAT; Unix.O_RDWR]
   
-external external_start : string -> unit = "external_start"
+external external_start : unit -> unit = "external_start"
 external external_exit : unit -> unit = "external_exit"
 external uname : unit -> string = "ml_uname"
-  
-(* CryptoPP *)
-external create_key : unit -> string = "ml_createKey"
-external load_key : string -> string = "ml_loadKey"
-external create_signature : string -> int -> int64 -> int -> int64 -> string = "ml_createSignature"
-external verify_signature : string -> int -> string -> int -> int64 -> int -> int64 -> bool = "ml_verifySignature_bytecode" "ml_verifySignature"
+external os_supported : unit -> bool = "ml_os_supported"
   
 (* let really_write fd s pos len =
   try
