@@ -119,7 +119,8 @@ let nb_sockets = ref 0
 let allow_read = ref true
 let allow_write = ref true
 
-let infinite_timeout = 3600. *. 24. *. 365. (* one year ! *)
+(*let infinite_timeout = 3600. *. 24. *. 365. (* one year ! *) *)
+let infinite_timeout = float_of_int Date.year_in_secs
 let current_time = ref (Unix.gettimeofday ())
 let last_time = ref (int_of_float (!current_time -. 1000000000.))
 
@@ -236,6 +237,7 @@ let must_write t b  =
     t.want_to_write <- b;
     change_fd_event_setting t
   end
+
 let must_read t b  =
   if b <> t.want_to_read then begin
     t.want_to_read <- b;
@@ -243,9 +245,8 @@ let must_read t b  =
   end
 
 let print_socket buf s =
-  Printf.bprintf buf "FD %s:%d: %20s"
+  Printf.bprintf buf "FD %s:%d"
      (s.name) (get_fd_num s.fd)
-  (Date.to_string s.born)
 
 let sprint_socket s =
   let buf = Buffer.create 100 in
@@ -260,9 +261,8 @@ let sprint_socket s =
 
 let close t msg =
   if t.fd <> dummy_fd then begin
-      if !debug then begin
-          lprintf "CLOSING: %s" (sprint_socket t);
-        end;
+      if !debug then
+          lprintf_nl "[bS] CLOSING: %s" (sprint_socket t);
       (try
           Unix.close t.fd;
           with _ -> ());
@@ -286,7 +286,7 @@ let dump_basic_socket buf = ()
 
 let create_blocking name fd handler =
 
-  let (fdnum : int) = get_fd_num fd in
+  let (_ : int) = get_fd_num fd in
 (*
   if fdnum >= Unix32.fds_size then begin
       Unix.close fd;
@@ -329,9 +329,8 @@ let create_blocking name fd handler =
       can_close = true;
     } in
 (*  lprintf "ADD ONE TASK\n"; *)
-  if !debug then begin
-      lprintf_nl "OPENING: %s" ( sprint_socket t);
-    end;
+  if !debug then
+      lprintf_nl "[bS] OPENING: %s" ( sprint_socket t);
   fd_tasks := t :: !fd_tasks;
   add_fd_to_event_set t;
   t
@@ -346,7 +345,7 @@ let create_blocking name fd handler =
 
 let create name fd handler =
   MlUnix.set_nonblock fd;
-  if Autoconf.system <> "windows" then setsockopt fd SO_KEEPALIVE !socket_keepalive;
+  if not Autoconf.windows then setsockopt fd SO_KEEPALIVE !socket_keepalive;
   create_blocking name fd handler
 
 
@@ -362,7 +361,7 @@ let rec iter_task old_tasks time =
   | t :: old_tail ->
 (*      lprintf "NEXT TASK\n"; *)
       if t.closed then begin
-          remove_fd_from_event_set t;
+          if t.fd <> dummy_fd then remove_fd_from_event_set t;
           iter_task old_tail time
        end else
         begin
@@ -514,10 +513,17 @@ let loop () =
         lprintf_nl "[BW1] Resetting bandwidth counters";
       List.iter (fun f -> try f () with _ -> ()) !bandwidth_second_timers
   );
+  let loop_time = ref 0. in
   while true do
     try
-      if !loop_delay > 0. then (try select [] !loop_delay;  with _ -> ());
-      let time = update_time () in
+      let time = 
+ 	let new_time = update_time () in
+ 	let dynamic_loop_delay =  !loop_time +. !loop_delay -. new_time in
+        if dynamic_loop_delay > 0. then begin
+ 	  (try select [] dynamic_loop_delay;  with _ -> ());
+ 	  update_time ()
+ 	end else new_time in
+      loop_time := time;
       exec_tasks !fd_tasks;
       exec_hooks !after_select_hooks;
       exec_timers !timers;
@@ -550,7 +556,7 @@ timeout := 5.;
 *)
       exec_hooks !before_select_hooks;
 (*      lprintf "Tasks %d\n" (List.length !fd_tasks); *)
-      select !fd_tasks !timeout;
+      try select !fd_tasks !timeout with _ -> ();
     with
     | e ->
         lprintf_nl "Exception %s in Select.loop" (Printexc2.to_string e);
@@ -629,6 +635,9 @@ let current_time () = !current_time
 
 let _ =
   Heap.add_memstat "BasicSocket" (fun level buf ->
+      Printf.bprintf buf "  before_select_hooks: %d\n" (List.length !before_select_hooks);
+      Printf.bprintf buf "  after_select_hooks: %d\n" (List.length !after_select_hooks);
+      Printf.bprintf buf "  bandwidth_second_timers: %d\n" (List.length !bandwidth_second_timers);
       Printf.bprintf buf "  %d timers\n" (List.length !timers);
       Printf.bprintf buf "  %d fd_tasks:\n" (List.length !fd_tasks);
       if level > 0 then
@@ -638,14 +647,6 @@ let _ =
         List.iter (fun t -> t.dump_info buf) !closed_tasks;
   );
 
-  Printexc2.register_exn (fun e ->
-      match e with
-        Unix.Unix_error (e, f, arg) ->
-          Printf.sprintf "%s failed%s: %s" f (if arg = "" then "" else
-              "on " ^ arg) (Unix.error_message e)
-      | _ -> raise e
-  );
-
   add_timer 300. (fun t ->
       reactivate_timer t;
       if !debug then
