@@ -17,6 +17,7 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *)
 
+open Int64ops
 open Printf2
 type t =  int * int * int * int
 
@@ -48,20 +49,18 @@ let to_fixed_string ((a4, a3, a2, a1) as t)=
   with _ ->
       Printf.sprintf "%03d.%03d.%03d.%03d" a4 a3 a2 a1
 
-let to_int64  ((a4, a3, a2, a1) as t) =
-  let small = a1 + 256 * (a2 + 256 * a3) in
-  Int64.add (Int64.of_int small) (Int64.shift_left (Int64.of_int a4) 24)
-
-let const_int32_255 = Int64.of_int 255
+let to_int64 (a4, a3, a2, a1) =
+  let small = a1 lor (a2 lsl 8) lor (a3 lsl 16) in
+  (Int64.of_int small) ++ (Int64.shift_left (Int64.of_int a4) 24)
 
 let of_int64 i =
-  let a4 = Int64.to_int (Int64.logand (Int64.shift_right i 24) const_int32_255)
+  let a4 = Int64.to_int (Int64.logand (Int64.shift_right i 24) 0xffL)
   in
-  let a3 = Int64.to_int (Int64.logand (Int64.shift_right i 16) const_int32_255)
+  let a3 = Int64.to_int (Int64.logand (Int64.shift_right i 16) 0xffL)
   in
-  let a2 = Int64.to_int (Int64.logand (Int64.shift_right i 8) const_int32_255)
+  let a2 = Int64.to_int (Int64.logand (Int64.shift_right i 8) 0xffL)
   in
-  let a1 = Int64.to_int (Int64.logand i const_int32_255)
+  let a1 = Int64.to_int (Int64.logand i 0xffL)
   in
   (a4, a3, a2, a1)
 
@@ -96,17 +95,20 @@ let local_ip ip =
 let reachable ip =
   !allow_local_network || not (local_ip ip)
 
+let usable ip =
+  reachable ip && valid ip
+
 let rec matches ((a4,a3,a2,a1) as a) ips =
   match ips with
     [] -> false
-  | ((b4,b3,b2,b1) as b) :: tail ->
+  | (b4,b3,b2,b1) :: tail ->
       ( (a4 = b4 || b4 = 255) &&
         (a3 = b3 || b3 = 255) &&
         (a2 = b2 || b2 = 255) &&
         (a1 = b1 || b1 = 255))
       || (matches a tail)
 
-let compare ((a4,a3,a2,a1) as a) ((b4,b3,b2,b1) as b) =
+let compare (a4,a3,a2,a1) (b4,b3,b2,b1) =
   let c4 = compare a4 b4 in
   if c4 <> 0 then c4 else
   let c3 = compare a3 b3 in
@@ -115,6 +117,30 @@ let compare ((a4,a3,a2,a1) as a) ((b4,b3,b2,b1) as b) =
   if c2 <> 0 then c2 else
   compare a1 b1
 
+let succ (a4,a3,a2,a1) =
+  if a1 < 255 then
+    (a4,a3,a2,a1+1)
+  else if a2 < 255 then
+    (a4,a3,a2+1,0)
+  else if a3 < 255 then
+    (a4,a3+1,0,0)
+  else if a4 < 255 then
+    (a4+1,0,0,0)
+  else
+    (0,0,0,0) (* or exception ? *)
+
+let pred (a4,a3,a2,a1) =
+  if a1 > 0 then
+    (a4,a3,a2,a1-1)
+  else if a2 > 0 then
+    (a4,a3,a2-1,255)
+  else if a3 > 0 then
+    (a4,a3-1,255,255)
+  else if a4 > 0 then
+    (a4-1,255,255,255)
+  else
+    (255,255,255,255) (* or exception ? *)
+
 let localhost = of_string "127.0.0.1"
 
 let to_sockaddr ip port =
@@ -155,7 +181,7 @@ let resolve_name name =
       with _ -> ip
     else ip
   with _ ->
-      lprintf_nl "[DNS]: Resolving [%s] ..." name;
+      lprintf_nl "[DNS] Resolving [%s] ..." name;
       let ip = gethostbyname name in
       Hashtbl.add ip_cache name (ip, current_time +. 3600.);
       ip
@@ -233,7 +259,7 @@ let async_ip name f =
 
 (* We check for names every 1/10 second. Too long ? *)
 let _ =
-  Heap.add_memstat "IP" (fun level buf ->
+  Heap.add_memstat "Ip" (fun level buf ->
       Printf.bprintf buf "  %d IPs in ip_cache\n" (Hashtbl.length ip_cache);
       Printf.bprintf buf "  %d entries in hostname_table\n" (Hashtbl.length hostname_table);
       Printf.bprintf buf "  %d entries in ip_fifo\n" (Fifo.length ip_fifo);
@@ -283,7 +309,7 @@ let _ =
                     Hashtbl.add ip_cache job.name (ip, current_time +. 3600.);
                     job.handler ip
                   end else begin
-                    lprintf "[DNS]: lookup error: %s: address not found\n" job.name;
+                    lprintf_nl "[DNS] could not resolve %s, check URL" job.name;
                     raise Not_found
                   end
               end else raise Exit
